package armazenamento;

import java.util.List;

import hibernate.HibernateTransaction;

import negocio.exception.PlanoExistenteException;
import negocio.exception.PlanoInexistenteException;

import org.hibernate.ObjectNotFoundException;
import org.hibernate.PropertyValueException;
import org.hibernate.Session;
import org.hibernate.exception.ConstraintViolationException;

import util.IteratorBidirecional;

import dados.exception.PlanoInvalidoException;
import dados.usuario.Plano;

public class RepositorioPlano {

	private static RepositorioPlano instancia;

	static{
		RepositorioPlano.instancia = new RepositorioPlano();
	}

	public RepositorioPlano() {}

	public static RepositorioPlano getInstancia(){
		return RepositorioPlano.instancia;
	}

	public void inserirPlano(Plano plano) throws PlanoInvalidoException, PlanoExistenteException{
		if(plano != null){
			HibernateTransaction busca = new HibernateTransaction();

			try{
				busca.openSessionBegin();
				Session sessao = busca.getSession();
				
				// AUTO INCREMENT!!!
				try{
					plano.setId((Long)sessao.createQuery("select max(p.id) from dados.usuario.Plano p").list().get(0) + 1);
				}catch(NullPointerException e){
					plano.setId(0);
				}

				sessao.save(plano);

				busca.closeSessionCommit();
			}catch(ConstraintViolationException e){
				busca.transactionRollBack();
				throw new PlanoExistenteException(plano.getNome());
			}catch(PropertyValueException e){
				busca.transactionRollBack();
				throw new PlanoInvalidoException();
			}
		}else{
			throw new IllegalArgumentException();
		}
	}

	public boolean existePlano(String nome){
		boolean retorno = true;

		try{
			this.buscarPlano(nome);
		} catch (PlanoInexistenteException e){
			retorno = false;
		}

		return retorno;
	}

	public Plano buscarPlano(String nome) throws PlanoInexistenteException{
		HibernateTransaction busca = new HibernateTransaction();
		Plano plano = null;

		try{
			Session sessao = busca.openSession();
			plano = (Plano) sessao.get(Plano.class, nome);

			if(plano != null){
				busca.closeSession();
				return plano;
			}else{
				busca.closeSession();
				throw new PlanoInexistenteException();
			}
		}catch(ObjectNotFoundException e){
			busca.closeSession();
			throw new PlanoInexistenteException();
		}
	}

	@SuppressWarnings("unchecked")
	public Plano buscarPlano(long id) throws PlanoInexistenteException{
		HibernateTransaction busca = new HibernateTransaction();

		try{
			List<Plano> lista = (List<Plano>) busca.openSession().createQuery(String.format("from dados.usuario.Plano where id = %d", id)).list();

			if(!lista.isEmpty()){
				busca.closeSession();
				return lista.get(0);
			}else{
				busca.closeSession();
				throw new PlanoInexistenteException();
			}
		}catch(ObjectNotFoundException e){
			busca.closeSession();
			throw new PlanoInexistenteException();
		}
	}

	public void removerPlano(Plano plano) throws PlanoInexistenteException{
		HibernateTransaction h = new HibernateTransaction();

		try{
			h.openSessionBegin();

			Session s = h.getSession();
			s.delete(plano);

			h.closeSessionCommit();
		}catch(ObjectNotFoundException e){
			h.transactionRollBack();
			throw new PlanoInexistenteException();
		}

	}

	public void mudarDados(Plano atual, Plano dados) throws PlanoInvalidoException, PlanoInexistenteException{
		if(atual != null && dados != null){
			atual.setDescricao(dados.getDescricao());
			atual.setMensalidade(dados.getMensalidade());
			atual.setFoto(dados.getFoto());
			atual.setLocacoesGratuitas(dados.getLocacoesGratuitas());

			HibernateTransaction busca = new HibernateTransaction();

			try{
				busca.openSessionBegin();
				Session sessao = busca.getSession();

				sessao.update(atual);

				busca.closeSessionCommit();
			}catch(PropertyValueException e){
				busca.transactionRollBack();
				throw new PlanoInvalidoException();
			}
		} else {
			throw new IllegalArgumentException();
		}
	}

	@SuppressWarnings("unchecked")
	public IteratorBidirecional<Plano> getPlanos() throws PlanoInexistenteException {
		HibernateTransaction busca = new HibernateTransaction();
		IteratorBidirecional<Plano> iterador = null;

		try{
			List<Plano> lista = (List<Plano>) busca.openSession().createQuery("from dados.usuario.Plano").list();

			if(!lista.isEmpty()){
				busca.closeSession();
				iterador = new IteratorBidirecional<Plano>(lista.iterator());
			}else{
				busca.closeSession();
				throw new PlanoInexistenteException();
			}
		}catch(ObjectNotFoundException e){
			busca.closeSession();
			throw new PlanoInexistenteException();
		}

		return iterador;
	}

}
