package armazenamento;

import java.util.List;

import hibernate.HibernateTransaction;
import negocio.exception.PromocaoExistenteException;
import negocio.exception.PromocaoInexistenteException;

import org.hibernate.ObjectNotFoundException;
import org.hibernate.PropertyValueException;
import org.hibernate.Session;
import org.hibernate.exception.ConstraintViolationException;

import util.IteratorBidirecional;

import dados.exception.PromocaoInvalidaException;
import dados.locacao.Promocao;

public class RepositorioPromocao {

	private static RepositorioPromocao instancia;

	static{
		RepositorioPromocao.instancia = new RepositorioPromocao();
	}

	private RepositorioPromocao(){}


	public static RepositorioPromocao getInstancia(){
		return RepositorioPromocao.instancia;
	}

	public void cadastrarProcomao(Promocao promocao) throws PromocaoInvalidaException, PromocaoExistenteException{
		if(promocao != null){
			HibernateTransaction busca = new HibernateTransaction();

			try{
				busca.openSessionBegin();
				Session sessao = busca.getSession();

				// AUTO INCREMENT!!!
				try{
					promocao.setId((Long)sessao.createQuery("select max(p.id) from dados.locacao.Promocao p").list().get(0) + 1);
				}catch(NullPointerException e){
					promocao.setId(0);
				}

				sessao.save(promocao);

				busca.closeSessionCommit();
			}catch(ConstraintViolationException e){
				busca.transactionRollBack();

				String retorno = e.getSQLException().getMessage();

				if(retorno.contains("key 1")){
					throw new PromocaoExistenteException(promocao);
				} 

			}catch(PropertyValueException e){
				busca.transactionRollBack();
				throw new PromocaoInvalidaException();
			}
		}else{
			throw new IllegalArgumentException();
		}
	}

	public void mudarDescricaoPromocao(Promocao promocao, String novaDescricao) throws PromocaoInvalidaException{
		if(promocao != null && novaDescricao != null){
			promocao.setDescricao(novaDescricao);

			HibernateTransaction busca = new HibernateTransaction();

			try{
				busca.openSessionBegin();
				Session sessao = busca.getSession();

				sessao.update(promocao);

				busca.closeSessionCommit();
			}catch(PropertyValueException e){
				busca.transactionRollBack();
				throw new PromocaoInvalidaException();
			}
		} else {
			throw new IllegalArgumentException();
		}
	}

	public void removerPromocao(String nome) throws PromocaoInexistenteException{
		Promocao promocao = RepositorioPromocao.instancia.getPromocao(nome);

		HibernateTransaction busca = new HibernateTransaction();
		busca.openSessionBegin();
		Session sessao = busca.getSession();

		sessao.delete(promocao);

		busca.closeSessionCommit();
	}

	public boolean existePromocao(String nome){
		boolean retorno = true;

		try{
			this.getPromocao(nome);
		} catch(PromocaoInexistenteException e){
			retorno = false;
		}

		return retorno;
	}

	public Promocao getPromocao(String nome) throws PromocaoInexistenteException{
		HibernateTransaction busca = new HibernateTransaction();

		try{
			Session sessao = busca.openSession();
			Promocao promocao = (Promocao) sessao.get(Promocao.class, nome);

			if(promocao != null){
				busca.closeSession();
				return promocao;
			}else{
				busca.closeSession();
				throw new PromocaoInexistenteException();
			}
		}catch(ObjectNotFoundException e){
			busca.closeSession();
			throw new PromocaoInexistenteException();
		}
	}
	
	@SuppressWarnings("unchecked")
	public Promocao buscarPromocao(long id) throws PromocaoInexistenteException{
		HibernateTransaction busca = new HibernateTransaction();

		try{
			List<Promocao> lista = (List<Promocao>) busca.openSession().createQuery(String.format("from dados.locacao.Promocao where id = %d", id)).list();

			if(!lista.isEmpty()){
				busca.closeSession();
				return lista.get(0);
			}else{
				busca.closeSession();
				throw new PromocaoInexistenteException();
			}
		}catch(ObjectNotFoundException e){
			busca.closeSession();
			throw new PromocaoInexistenteException();
		}
	}

	@SuppressWarnings("unchecked")
	public IteratorBidirecional<Promocao> getPromocoes() throws PromocaoInexistenteException{
		HibernateTransaction busca = new HibernateTransaction();
		IteratorBidirecional<Promocao> iterador = null;

		try{
			List<Promocao> lista = (List<Promocao>) busca.openSession().createQuery("from dados.locacao.Promocao").list();

			if(!lista.isEmpty()){
				busca.closeSession();
				iterador = new IteratorBidirecional<Promocao>(lista.iterator());
			}else{
				busca.closeSession();
				throw new PromocaoInexistenteException();
			}
		}catch(ObjectNotFoundException e){
			busca.closeSession();
			throw new PromocaoInexistenteException();
		}

		return iterador;
	}
}
