package armazenamento.usuario;

import hibernate.HibernateTransaction;

import java.util.Hashtable;
import java.util.List;
import java.util.Random;
import java.util.Set;
import java.util.Map.Entry;

import negocio.exception.UsuarioExistenteException;
import negocio.exception.UsuarioInexistenteException;

import org.hibernate.ObjectNotFoundException;
import org.hibernate.PropertyValueException;
import org.hibernate.Session;
import org.hibernate.exception.ConstraintViolationException;

import util.IteratorBidirecional;

import dados.usuario.Administrador;
import dados.usuario.Cliente;
import dados.usuario.Dependente;
import dados.usuario.Funcionario;
import dados.usuario.Usuario;

public class RepositorioUsuario {

	private Hashtable<Long, Usuario> login;

	private static RepositorioUsuario instancia;

	static{
		RepositorioUsuario.instancia = new RepositorioUsuario();
	}

	public RepositorioUsuario() {
		this.login = new Hashtable<Long, Usuario>();
	}
	
	public static RepositorioUsuario getInstancia(){
		return RepositorioUsuario.instancia;
	}

	public long logarUsuario(Usuario usuario){
		if(usuario != null){
			Random random = new Random();
			long sessao = 0;

			while(usuario != null){
				sessao = random.nextLong();

				if(!this.login.containsKey(sessao)){
					this.login.put(sessao, usuario);
					usuario = null;
				}
			}
			
			return sessao;
		}else{
			throw new IllegalArgumentException();
		}
	}

	public void deslogarSessao(long sessao){
		if(this.login.containsKey(sessao)){
			this.login.remove(sessao);
		}else{
			throw new IllegalArgumentException();
		}
	}

	public boolean estaLogado(long sessao){
		return this.login.containsKey(sessao);
	}
	
	public boolean estaLogado(Usuario usuario){
		if(usuario != null){
			return this.login.containsValue(usuario);
		}else{
			throw new IllegalArgumentException();
		}
	}

	public void cadastrarUsuario(Usuario usuario) throws UsuarioExistenteException{
		if(usuario != null){
			HibernateTransaction busca = new HibernateTransaction();
			
			try{
				busca.openSessionBegin();
				Session sessao = busca.getSession();

				sessao.save(usuario);

				busca.closeSessionCommit();
			}catch(ConstraintViolationException e){
				busca.transactionRollBack();
				
				String retorno = e.getSQLException().getMessage();

				if(retorno.contains("key 1")){
					throw new UsuarioExistenteException(usuario.getCpf());
				}else{
					throw new UsuarioExistenteException(usuario.getEmail());
				}
			}catch(PropertyValueException e){
				// NAO deve dar
			}
		}else{
			throw new IllegalArgumentException();
		}
	}

	public void removerUsuario(long cpf) throws UsuarioInexistenteException{
		Usuario usuario = this.getUsuario(cpf);
		
		HibernateTransaction busca = new HibernateTransaction();
		busca.openSessionBegin();
		Session sessao = busca.getSession();

		if(usuario instanceof Cliente){
			Cliente c = (Cliente) usuario;
			sessao.delete(c);
			sessao.delete(c.getEndereco());
		}else if(usuario instanceof Funcionario){
			Funcionario f = (Funcionario) usuario;
			sessao.delete(f);
		} else if(usuario instanceof Dependente){
			Dependente d = (Dependente) usuario;
			sessao.delete(d);
		}else{
			Administrador a = (Administrador) usuario;
			sessao.delete(a);
		}

		busca.closeSessionCommit();
		
		if(this.login.contains(usuario)){
			long s = 0;
			Set<Entry<Long, Usuario>> conj = this.login.entrySet();
			
			for (Entry<Long, Usuario> entry : conj) {
				if(entry.getValue().equals(usuario)){
					s = entry.getKey();
				}
			}
			
			this.login.remove(s);
		}
	}
	
	public void alterarDados(Usuario user, Usuario dados) throws UsuarioExistenteException{
		if(user != null && dados != null){
			user.setDados(dados);
			
			HibernateTransaction busca = new HibernateTransaction();

			try{
				busca.openSessionBegin();
				Session sessao = busca.getSession();
				
				sessao.update(user);
				
				busca.closeSessionCommit();
			}catch(ConstraintViolationException e){
				busca.transactionRollBack();
				
				String retorno = e.getSQLException().getMessage();

				if(retorno.contains("key 1")){
					// NAO vai acontecer
				}else{
					throw new UsuarioExistenteException(user.getEmail());
				}
			}catch(PropertyValueException e){
				//NAO deve dar
			}
		}else{
			throw new IllegalArgumentException();
		}
	}


	public boolean existeUsuario(long cpf){
		boolean retorno = true;

		try{
			this.getUsuario(cpf);
		}catch(UsuarioInexistenteException e){
			retorno = false;
		}

		return retorno;
	}

	public Usuario getUsuario(long cpf) throws UsuarioInexistenteException{
		HibernateTransaction busca = new HibernateTransaction();
		Usuario usuario = null;
		
		try{
			Session sessao = busca.openSession();
			usuario = (Usuario) sessao.get(Usuario.class, cpf);
			
			if(usuario != null){
				busca.closeSession();
				return usuario;
			}else{
				busca.closeSession();
				throw new UsuarioInexistenteException(cpf);
			}
		}catch(ObjectNotFoundException e){
			busca.closeSession();
			throw new UsuarioInexistenteException(cpf);
		}
	}
	
	public Usuario getUsuarioLogado(long sessao){
		return this.login.get(sessao);
	}

	@SuppressWarnings("unchecked")
	public IteratorBidirecional<Usuario> getUsuarios() throws UsuarioInexistenteException{
		HibernateTransaction busca = new HibernateTransaction();
		IteratorBidirecional<Usuario> iterador = null;
		
		try{
			List<Usuario> lista = (List<Usuario>) busca.openSession().createQuery("from dados.usuario.Usuario").list();
			
			if(!lista.isEmpty()){
				busca.closeSession();
				iterador = new IteratorBidirecional<Usuario>(lista.iterator());
			}else{
				busca.closeSession();
				throw new UsuarioInexistenteException();
			}
		}catch(ObjectNotFoundException e){
			busca.closeSession();
			throw new UsuarioInexistenteException();
		}

		return iterador;
	}
	
	@SuppressWarnings("unchecked")
	public IteratorBidirecional<Funcionario> getFuncionarios() throws UsuarioInexistenteException{
		HibernateTransaction busca = new HibernateTransaction();
		IteratorBidirecional<Funcionario> iterador = null;
		
		try{
			List<Funcionario> lista = (List<Funcionario>) busca.openSession().createQuery("from dados.usuario.Funcionario").list();
			
			if(!lista.isEmpty()){
				busca.closeSession();
				iterador = new IteratorBidirecional<Funcionario>(lista.iterator());
			}else{
				busca.closeSession();
				throw new UsuarioInexistenteException();
			}
		}catch(ObjectNotFoundException e){
			busca.closeSession();
			throw new UsuarioInexistenteException();
		}

		return iterador;
	}
	
	@SuppressWarnings("unchecked")
	public IteratorBidirecional<Dependente> getDependentes(Cliente cliente) throws UsuarioInexistenteException{
		HibernateTransaction busca = new HibernateTransaction();
		IteratorBidirecional<Dependente> iterator = null;
		
		try{
			List<Dependente> lista = (List<Dependente>) busca.openSession().createQuery(String.format("from dados.usuario.Dependente where dependente_cliente_cpf = %d", cliente.getCpf())).list();
			
			if(!lista.isEmpty()){
				busca.closeSession();
				iterator = new IteratorBidirecional<Dependente>(lista.iterator());
			}else{
				busca.closeSession();
				throw new UsuarioInexistenteException();
			}
		}catch(ObjectNotFoundException e){
			busca.closeSession();
			throw new UsuarioInexistenteException();
		}

		return iterator;
	}

}
