package negocio;

import util.IteratorBidirecional;

import negocio.exception.FilialExistenteException;
import negocio.exception.FilialInexistenteException;
import negocio.exception.FilialLogadaException;
import negocio.exception.FilialNaoLogadaException;
import dados.exception.FilialInvalidaException;
import dados.filial.Filial;
import armazenamento.filial.RepositorioFilial;

public class GerenciadorFilial {

	private static GerenciadorFilial instancia;
	private RepositorioFilial repositorio;

	static{
		GerenciadorFilial.instancia = new GerenciadorFilial();
	}

	private GerenciadorFilial(){
		this.repositorio = RepositorioFilial.getInstancia();
	}

	public static GerenciadorFilial getInstancia(){
		return GerenciadorFilial.instancia;
	}

	public void cadastraFilial(Filial filial) throws FilialExistenteException, FilialInvalidaException{
		if(filial != null){
			if(!this.repositorio.existeFilial(filial.getNome())){
				this.repositorio.cadastrarFilial(filial);
			} else {
				throw new FilialExistenteException(filial);
			}
		} else {
			throw new IllegalArgumentException();
		}
	}

	public void removerFilial(String id) throws FilialInexistenteException{
		if(id != null){
			if(this.repositorio.existeFilial(id)){
				this.repositorio.removerFilial(id);
			} else {
				throw new FilialInexistenteException();
			}
		} else {
			throw new IllegalArgumentException();
		}
	}

	public Filial buscarFilial(String id) throws FilialInexistenteException{
		if(id != null){
			if(this.repositorio.existeFilial(id)){
				return this.repositorio.getFilial(id);
			} else {
				throw new FilialInexistenteException();
			}
		}else{
			throw new IllegalArgumentException();
		}
	}

	public Filial buscarFilial(long id) throws FilialInexistenteException{
		return this.repositorio.getFilial(id);
	}

	public boolean existeFilial(String id){
		if(id != null){
			return this.repositorio.existeFilial(id);
		}else{
			throw new IllegalArgumentException();
		}
	}

	public IteratorBidirecional<Filial> getFiliais() throws FilialInexistenteException{
		return this.repositorio.getFiliais();
	}

	public void atualizarFilial(Filial dados) throws FilialInexistenteException, FilialInvalidaException{
		if(dados != null){
			if(this.repositorio.existeFilial(dados.getNome())){
				Filial atual = this.repositorio.getFilial(dados.getNome());
				this.repositorio.atualizarFilial(atual, dados);
			} else{
				throw new FilialInexistenteException();
			}
		} else {
			throw new IllegalArgumentException();
		}
	}

	public void logarFilial(Filial filial) throws FilialLogadaException, FilialInexistenteException{
		if(this.existeFilial(filial.getNome())){
			if(!this.repositorio.estaLogada(filial.getNome())){
				this.repositorio.logarFilial(filial);
			} else {
				throw new FilialLogadaException(filial.getNome());
			}
		} else {
			throw new FilialInexistenteException();
		}
	}

	public void deslogarFilial(String nome) throws FilialNaoLogadaException, FilialInexistenteException{
		if(this.existeFilial(nome)){
			if(this.repositorio.estaLogada(nome)){
				this.repositorio.deslogarFilial(nome);
			} else {
				throw new FilialNaoLogadaException(nome);
			}
		} else {
			throw new FilialInexistenteException();
		}
	}

	public boolean estaLogada(String nome){
		return this.repositorio.estaLogada(nome);
	}

}
