package negocio;

import util.IteratorBidirecional;

import negocio.exception.PlanoExistenteException;
import negocio.exception.PlanoInexistenteException;
import armazenamento.RepositorioPlano;
import dados.exception.PlanoInvalidoException;
import dados.usuario.Plano;

public class GerenciadorPlano {
	
	private static GerenciadorPlano instancia;
	
	private RepositorioPlano repositorio;
	
	static {
		GerenciadorPlano.instancia = new GerenciadorPlano();
	}
	
	private GerenciadorPlano(){
		this.repositorio = RepositorioPlano.getInstancia();
	}
	
	public static GerenciadorPlano getInstancia(){
		return GerenciadorPlano.instancia;
	}
	
	public void cadastrarPlano(Plano novoPlano) throws PlanoInvalidoException, PlanoExistenteException{
		if(novoPlano != null){
			if(!this.repositorio.existePlano(novoPlano.getNome())){
				this.repositorio.inserirPlano(novoPlano);
			} else {
				throw new PlanoExistenteException(novoPlano.getNome());
			}
		} else{
			throw new IllegalArgumentException();
		}
	}
	
	public void descadastrarPlano(String nome) throws PlanoInexistenteException{
		if(nome != null){
			if(this.repositorio.existePlano(nome)){
				Plano plano = this.repositorio.buscarPlano(nome);
				this.repositorio.removerPlano(plano);
			} else {
				throw new PlanoInexistenteException();
			}
		} else{
			throw new IllegalArgumentException();
		}
	}
	
	public boolean existePlano(String nome){
		return this.repositorio.existePlano(nome);
	}
	
	public Plano buscarPlano(String nome) throws PlanoInexistenteException{
		if(nome != null){
			if(this.repositorio.existePlano(nome)){
				return this.repositorio.buscarPlano(nome);
			} else {
				throw new PlanoInexistenteException();
			}
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public Plano buscarPlano(long id) throws PlanoInexistenteException{
		return this.repositorio.buscarPlano(id);
	}
	
	public IteratorBidirecional<Plano> getPlanos() throws PlanoInexistenteException{
		return this.repositorio.getPlanos();
	}

	public void atualizarPlano(Plano atual) throws PlanoInvalidoException, PlanoInexistenteException {
		this.repositorio.mudarDados(this.repositorio.buscarPlano(atual.getId()), atual);
	}
	
}
