package negocio.locacao;

import util.IteratorBidirecional;

import negocio.exception.CopiaLocadaNoPeriodoException;
import negocio.exception.LocacaoExistenteException;
import negocio.exception.LocacaoInexistenteException;
import dados.exception.LocacaoInvalidaException;
import dados.locacao.Copia;
import dados.locacao.Locacao;
import dados.locacao.Periodo;
import dados.usuario.Cliente;
import armazenamento.RepositorioLocacao;

public class GerenciadorLocacao {
	
	private static GerenciadorLocacao instancia;
	private RepositorioLocacao repositorio;
	
	static{
		GerenciadorLocacao.instancia = new GerenciadorLocacao();
	}
	
	private GerenciadorLocacao(){
		this.repositorio = RepositorioLocacao.getInstancia();
	}
	
	public static GerenciadorLocacao getInstancia(){
		return GerenciadorLocacao.instancia;
	}
	
	public void inserirLocacao(Locacao locacao) throws LocacaoExistenteException, LocacaoInvalidaException, CopiaLocadaNoPeriodoException{
		if(locacao != null){
			if(!this.repositorio.existeLocacao(locacao.getCopia())){
				try {
					this.repositorio.getLocacoesInterceptaPeriodo(locacao.getCopia(), locacao.getPeriodo());
					throw new CopiaLocadaNoPeriodoException(locacao.getCopia(), locacao.getPeriodo());
				} catch (LocacaoInexistenteException e) {
					this.repositorio.inserirLocacao(locacao);
				}
			} else{
				throw new LocacaoExistenteException();
			}
		} else{
			throw new IllegalArgumentException();
		}
	}
	
	public void removerLocacao(Locacao locacao) throws LocacaoInexistenteException{
		if(locacao != null){
			if(this.repositorio.existeLocacao(locacao.getCopia())){
				this.repositorio.removerLocacao(locacao.getCopia());
			} else {
				throw new LocacaoInexistenteException();
			}
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public boolean existeLocacao(Copia copia){
		return this.repositorio.existeLocacao(copia);
	}
	
	public Locacao buscarLocacao(Copia copia) throws LocacaoInexistenteException{
		if(this.repositorio.existeLocacao(copia)){
			return this.repositorio.getLocacao(copia);
		} else {
			throw new LocacaoInexistenteException();
		}
	}
	
	public Locacao buscarLocacao(long id) throws LocacaoInexistenteException{
		return this.repositorio.getLocacao(id);
	}
	
	public IteratorBidirecional<Locacao> buscarLocacoes(Cliente cliente) throws LocacaoInexistenteException{
		if(cliente != null){
			return this.repositorio.getLocacoes(cliente);
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public IteratorBidirecional<Locacao> buscarLocacoesInterceptaPeriodo(Copia copia, Periodo periodo) throws LocacaoInexistenteException{
		return this.repositorio.getLocacoesInterceptaPeriodo(copia, periodo);
	}

}
