package negocio.locacao;

import util.IteratorBidirecional;

import negocio.exception.PromocaoExistenteException;
import negocio.exception.PromocaoInexistenteException;
import dados.exception.PromocaoInvalidaException;
import dados.locacao.Promocao;
import armazenamento.RepositorioPromocao;

public class GerenciadorPromocao {
	
	private static GerenciadorPromocao instancia;
	private RepositorioPromocao repositorio;

	static{
		GerenciadorPromocao.instancia = new GerenciadorPromocao();
	}
	
	private GerenciadorPromocao(){
		this.repositorio = RepositorioPromocao.getInstancia();
	}
	
	public static GerenciadorPromocao getInstancia(){
		return GerenciadorPromocao.instancia;
	}
	
	public void cadastrarPromocao(Promocao promocao) throws PromocaoInvalidaException, PromocaoExistenteException{
		if(promocao != null){
			if(!this.repositorio.existePromocao(promocao.getNome())){
				this.repositorio.cadastrarProcomao(promocao);
			} else {
				throw new PromocaoExistenteException(promocao);
			}
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public void removerPromocao(String nome) throws PromocaoInexistenteException{
		if(this.repositorio.existePromocao(nome)){
			this.repositorio.removerPromocao(nome);
		} else {
			throw new PromocaoInexistenteException();
		}
	}
	
	public boolean existePromocao(String nome){
		return this.repositorio.existePromocao(nome);
	}

	public Promocao buscarPromocao(String nome) throws PromocaoInexistenteException {
		if(this.repositorio.existePromocao(nome)){
			return this.repositorio.getPromocao(nome);
		} else {
			throw new PromocaoInexistenteException();
		}
	}
	
	public Promocao buscarPromocao(long id) throws PromocaoInexistenteException{
		return this.repositorio.buscarPromocao(id);
	}
	
	public void mudarDescricaoPromocao(Promocao promocao, String novaDescricao) throws PromocaoInexistenteException, PromocaoInvalidaException{
		if(promocao != null && novaDescricao != null){
			if(this.repositorio.existePromocao(promocao.getNome())){
				this.repositorio.mudarDescricaoPromocao(promocao, novaDescricao);
			} else {
				throw new PromocaoInexistenteException();
			}
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public IteratorBidirecional<Promocao> getPromocoes() throws PromocaoInexistenteException{
		return this.repositorio.getPromocoes();
	}
}
