package negocio.locacao;

import util.IteratorBidirecional;

import negocio.exception.CopiaReservadaNoPeriodoException;
import negocio.exception.ReservaExistenteException;
import negocio.exception.ReservaInexistenteException;
import dados.locacao.Copia;
import dados.locacao.Periodo;
import dados.locacao.Reserva;
import dados.usuario.Cliente;
import armazenamento.RepositorioReserva;

public class GerenciadorReserva {
	
	private static GerenciadorReserva instancia;
	private RepositorioReserva repositorio;
	
	static{
		GerenciadorReserva.instancia = new GerenciadorReserva();
	}
	
	private GerenciadorReserva(){
		this.repositorio = RepositorioReserva.getInstancia();
	}
	
	public static GerenciadorReserva getInstancia(){
		return GerenciadorReserva.instancia;
	}
	
	public void inserirReserva(Reserva reserva) throws ReservaExistenteException, CopiaReservadaNoPeriodoException{
		if(reserva != null){
			if(!this.repositorio.existeReserva(reserva.getCliente(), reserva.getCopia())){
				try {
					this.repositorio.getReservaInterceptaPeriodo(reserva.getCopia(), reserva.getPeriodo());
					throw new CopiaReservadaNoPeriodoException(reserva.getCopia(), reserva.getPeriodo());
				} catch (ReservaInexistenteException e) {
					this.repositorio.inserirReserva(reserva);
				}
			} else {
				throw new ReservaExistenteException(reserva);
			}
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public void removerReserva(Cliente cliente, Copia copia) throws ReservaInexistenteException{
		if(this.repositorio.existeReserva(cliente, copia)){
			this.repositorio.removerReserva(cliente, copia);
		} else {
			throw new ReservaInexistenteException();
		}
	}
	
	public boolean existeReserva(Cliente cliente, Copia copia){
		return this.repositorio.existeReserva(cliente, copia);
	}
	
	public Reserva buscarReserva(Cliente cliente, Copia copia) throws ReservaInexistenteException{
		if(this.repositorio.existeReserva(cliente, copia)){
			return this.repositorio.getReserva(cliente,copia);
		} else {
			throw new ReservaInexistenteException();
		}
	}
	
	public Reserva buscarReserva(long id) throws ReservaInexistenteException{
		return this.repositorio.getReserva(id);
	}
	
	public IteratorBidirecional<Reserva> buscarReservas(Copia copia) throws ReservaInexistenteException{
		if(copia != null){
			return this.repositorio.getReservas(copia);
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public IteratorBidirecional<Reserva> buscarReservas(Cliente cliente) throws ReservaInexistenteException{
		if(cliente != null){
			return this.repositorio.getReservas(cliente);
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public IteratorBidirecional<Reserva> buscarReservasInterceptaPeriodo(Copia copia, Periodo periodo) throws ReservaInexistenteException{
		return this.repositorio.getReservaInterceptaPeriodo(copia, periodo);
	}
}
