package negocio.produto;

import util.IteratorBidirecional;

import negocio.exception.AvaliacaoExistenteException;
import negocio.exception.AvaliacaoInexistenteException;
import dados.exception.AvaliacaoInvalidaException;
import dados.produto.AvaliacaoProduto;
import dados.produto.Produto;
import dados.usuario.Usuario;
import armazenamento.produto.RepositorioAvaliacaoProduto;

public class GerenciadorAvaliacaoProduto {

	private static GerenciadorAvaliacaoProduto instancia;
	
	private RepositorioAvaliacaoProduto repositorio;
	
	static{
		GerenciadorAvaliacaoProduto.instancia = new GerenciadorAvaliacaoProduto();
	}
	
	private GerenciadorAvaliacaoProduto(){
		this.repositorio = RepositorioAvaliacaoProduto.getInstancia();
	}
	
	public static GerenciadorAvaliacaoProduto getInstancia(){
		return GerenciadorAvaliacaoProduto.instancia;
	}
	
	public void avaliarProduto(AvaliacaoProduto avaliacao) throws AvaliacaoExistenteException, AvaliacaoInvalidaException{
		if(avaliacao != null){
			if(!this.repositorio.existeAvaliacao(avaliacao.getProduto(), avaliacao.getUsuario())){
				this.repositorio.avaliarProduto(avaliacao);
			} else {
				throw new AvaliacaoExistenteException(avaliacao.getUsuario().getCpf(), avaliacao.getProduto().getNome());
			}
		} else{
			throw new IllegalArgumentException();
		}
	}
	
	public void removerAvaliacao(Usuario usuario, Produto produto) throws AvaliacaoInexistenteException{
		if(usuario != null && produto != null){
			if(this.repositorio.existeAvaliacao(produto, usuario)){
				this.repositorio.removerAvaliacao(usuario, produto);
			} else {
				throw new AvaliacaoInexistenteException(usuario.getCpf(), produto.getNome());
			}
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public void removerAvaliacoes(Usuario usuario) throws AvaliacaoInexistenteException{
		this.repositorio.removerAvaliacoes(usuario);
	}
	
	public void removerAvaliacoes(Produto produto) throws AvaliacaoInexistenteException{
		this.repositorio.removerAvaliacoes(produto);
	}
	
	public boolean existeAvaliacao(Usuario usuario, Produto produto) throws AvaliacaoInexistenteException{
		return this.repositorio.existeAvaliacao(produto, usuario);
	}
	
	public AvaliacaoProduto buscarAvaliacaoProduto(Usuario usuario, Produto produto) throws AvaliacaoInexistenteException{
		if(usuario != null && produto != null){
			if(this.repositorio.existeAvaliacao(produto, usuario)){
				return this.repositorio.getAvaliacao(produto, usuario);
			} else {
				throw new AvaliacaoInexistenteException(usuario.getCpf(), produto.getNome());
			}
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public AvaliacaoProduto buscarAvaliacao(long id) throws AvaliacaoInexistenteException{
		return this.repositorio.getAvaliacaoProduto(id);
	}
	
	public void atualizarAvaliacao(AvaliacaoProduto dados) throws AvaliacaoInexistenteException, AvaliacaoInvalidaException{
		if(dados != null){
			if(this.repositorio.existeAvaliacao(dados.getProduto(), dados.getUsuario())){
				AvaliacaoProduto atual = this.repositorio.getAvaliacao(dados.getProduto(), dados.getUsuario());
				this.repositorio.atualizarAvaliacao(atual, dados);
			} else {
				throw new AvaliacaoInexistenteException(dados.getUsuario().getCpf(), dados.getProduto().getNome());
			}
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public IteratorBidirecional<AvaliacaoProduto> getAvaliacaoesProduto(Produto produto) throws AvaliacaoInexistenteException{
		if(produto != null){
			return this.repositorio.getAvaliacoesProduto(produto);
		} else {
			throw new IllegalArgumentException();
		}
	}
	
	public IteratorBidirecional<AvaliacaoProduto> getAvaliacaoesUsuario(Usuario usuario) throws AvaliacaoInexistenteException{
		if(usuario != null){
			return this.repositorio.getAvaliacoesUsuario(usuario);
		} else {
			throw new IllegalArgumentException();
		}
	}
	
}
