package servicos;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;

import javax.mail.Authenticator;
import javax.mail.Message;
import javax.mail.MessagingException;
import javax.mail.PasswordAuthentication;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;

import util.IteratorBidirecional;

import negocio.GerenciadorFilial;
import negocio.exception.AvaliacaoExistenteException;
import negocio.exception.AvaliacaoInexistenteException;
import negocio.exception.ClassificacaoExistenteException;
import negocio.exception.ClassificacaoInexistenteException;
import negocio.exception.CopiaExistenteException;
import negocio.exception.CopiaInexistenteException;
import negocio.exception.CopiaLocadaNoPeriodoException;
import negocio.exception.CopiaReservadaNoPeriodoException;
import negocio.exception.FilialExistenteException;
import negocio.exception.FilialInexistenteException;
import negocio.exception.FilialNaoLogadaException;
import negocio.exception.LinkFotoExistenteException;
import negocio.exception.LocacaoExistenteException;
import negocio.exception.LocacaoInexistenteException;
import negocio.exception.PlanoExistenteException;
import negocio.exception.PlanoInexistenteException;
import negocio.exception.ProdutoExistenteException;
import negocio.exception.ProdutoInexistenteException;
import negocio.exception.PromocaoExistenteException;
import negocio.exception.PromocaoInexistenteException;
import negocio.exception.ReservaInexistenteException;
import negocio.exception.UsuarioExistenteException;
import negocio.exception.UsuarioInexistenteException;
import negocio.exception.UsuarioNaoLogadoException;
import negocio.exception.UsuarioSemPermissaoException;
import dados.exception.AvaliacaoInvalidaException;
import dados.exception.EmailInvalidoException;
import dados.exception.FilialInvalidaException;
import dados.exception.LocacaoInvalidaException;
import dados.exception.PlanoInvalidoException;
import dados.exception.PrecoInvalidoException;
import dados.exception.ProdutoInvalidoException;
import dados.exception.PromocaoInvalidaException;
import dados.filial.Endereco;
import dados.filial.Filial;
import dados.locacao.Copia;
import dados.locacao.Locacao;
import dados.locacao.Periodo;
import dados.locacao.Promocao;
import dados.locacao.Reserva;
import dados.produto.AvaliacaoProduto;
import dados.produto.ClassificacaoPreco;
import dados.produto.LinkFoto;
import dados.produto.Produto;
import dados.usuario.Administrador;
import dados.usuario.Cliente;
import dados.usuario.Plano;
import dados.usuario.Telefone;
import dados.usuario.Usuario;

public class InterfaceWebBDImp extends InterfaceGeralImp implements InterfaceWebBD {

	private static final long serialVersionUID = 1L;

	private GerenciadorFilial gerenciadorFilial;

	public InterfaceWebBDImp() throws RemoteException {
		super();

		this.gerenciadorFilial = GerenciadorFilial.getInstancia();
	}

	@Override
	public synchronized void cadastrarCliente(Cliente cliente, Telefone[] telefone) throws RemoteException, UsuarioExistenteException, EmailInvalidoException {
		Properties props = new Properties();
		props.put("mail.transport.protocol", "smtp"); //define protocolo de envio como SMTP
		props.put("mail.smtp.starttls.enable","true");   
		props.put("mail.host", "mail.google.com"); 
		props.put("mail.smtp.host", "smtp.gmail.com"); //server SMTP do GMAIL
		props.put("mail.smtp.auth", "true"); //ativa autenticacao
		props.put("mail.debug", "true");
		props.put("mail.smtp.port", "465"); //porta
		props.put("mail.smtp.socketFactory.port", 465); //mesma porta para o socket
		props.put("mail.smtp.socketFactory.class", "javax.net.ssl.SSLSocketFactory");
		props.put("mail.smtp.socketFactory.fallback", "false");

		Authenticator auth = new Authenticator() {
			@Override
			protected PasswordAuthentication getPasswordAuthentication() {
				return new PasswordAuthentication("videosystem.locadora@gmail.com", "videosystempassword");
			}
		};

		Session session = Session.getDefaultInstance(props, auth);

		String msgBody = String.format("Ol %s,\nSua conta foi ativada com sucesso. Para logar no sistema online, utilize seu CPF cadastrado e a seguinte senha:\n\n%s\n\nAcesse nosso site! videosystem.com\nSugerimos que voc mude esta senha para uma nova que possa ser mais facilmente memorizada.\n\nObrigado pela preferncia!", cliente.getNome(), cliente.getSenha());

		try {
			Message msg = new MimeMessage(session);
			msg.addRecipient(Message.RecipientType.TO, new InternetAddress(cliente.getEmail()));
			msg.setSubject("Sua conta no VideoSystem foi ativada!");
			msg.setContent(msgBody, "text/plain");

			this.gerenciadorUsuario.cadastrarCliente(cliente, telefone);

			Transport.send(msg);
		} catch (AddressException e) {
			throw new EmailInvalidoException();
		} catch (MessagingException e) {
			try {
				this.gerenciadorUsuario.descadastrarUsuario(cliente);
			} catch (UsuarioInexistenteException e1) {
				// NAO deve ocorrer
				e1.printStackTrace();
			}

			throw new EmailInvalidoException();
		}

	}

	@Override
	public synchronized void alterarDadosProduto(long sessao, Produto dados) throws RemoteException, UsuarioSemPermissaoException, UsuarioNaoLogadoException, ProdutoInexistenteException, ProdutoInvalidoException, ProdutoExistenteException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorProduto.alterarDadosProduto(dados);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}
	}

	@Override
	public synchronized void atualizarFilial(long sessao, Filial dados) throws RemoteException, UsuarioNaoLogadoException, UsuarioSemPermissaoException, FilialInexistenteException, FilialInvalidaException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorFilial.atualizarFilial(dados);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}
	}

	@Override
	public synchronized Filial buscarFilial(String id) throws RemoteException, FilialInexistenteException {
		if(id != null){
			return this.gerenciadorFilial.buscarFilial(id);
		}else{
			throw new IllegalArgumentException();
		}
	}
	
	@Override
	public synchronized Filial buscarFilial(long id) throws FilialInexistenteException{
		return this.gerenciadorFilial.buscarFilial(id);
	}

	@Override
	public synchronized void cadastrarCopia(long sessao, Copia copia) throws RemoteException, UsuarioNaoLogadoException, UsuarioSemPermissaoException, CopiaExistenteException, ProdutoInexistenteException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorProduto.inserirCopia(copia);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}
	}

	@Override
	public synchronized void cadastrarFilial(long sessao, Filial filial) throws RemoteException, UsuarioNaoLogadoException, UsuarioSemPermissaoException, FilialExistenteException, FilialInvalidaException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorFilial.cadastraFilial(filial);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}
	}

	@Override
	public synchronized void cadastrarPlano(long sessao, Plano plano) throws RemoteException, UsuarioSemPermissaoException, UsuarioNaoLogadoException, PlanoInvalidoException, PlanoExistenteException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorPlano.cadastrarPlano(plano);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}
	}

	@Override
	public synchronized void cadastrarProduto(long sessao, Produto produto) throws RemoteException, UsuarioNaoLogadoException, UsuarioSemPermissaoException, ProdutoExistenteException, ProdutoInvalidoException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorProduto.inserirProduto(produto);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}
	}

	@Override
	public synchronized void cadastrarPromocao(long sessao, Promocao promocao) throws RemoteException, UsuarioSemPermissaoException, PromocaoInvalidaException, PromocaoExistenteException, UsuarioNaoLogadoException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorPromocao.cadastrarPromocao(promocao);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}
	}

	@Override
	public synchronized void descadastrarCopia(long sessao, String nomeProduto, int codigoCopia) throws RemoteException, UsuarioNaoLogadoException, UsuarioSemPermissaoException, ProdutoInexistenteException, CopiaInexistenteException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			Produto produto = this.gerenciadorProduto.buscarProduto(nomeProduto);
			Copia copia = produto.getCopia(codigoCopia);
			this.gerenciadorProduto.removerCopia(copia);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}
	}

	@Override
	public synchronized void descadastrarFilial(long sessao, String id) throws RemoteException, UsuarioNaoLogadoException, UsuarioSemPermissaoException, FilialInexistenteException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorFilial.removerFilial(id);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}	
	}

	@Override
	public synchronized void descadastrarPlano(long sessao, String nome) throws RemoteException, PlanoInexistenteException, UsuarioNaoLogadoException, UsuarioSemPermissaoException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorPlano.descadastrarPlano(nome);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}	
	}

	@Override
	public synchronized void descadastrarProduto(long sessao, String nomeProduto) throws RemoteException, ProdutoInexistenteException, UsuarioNaoLogadoException, UsuarioSemPermissaoException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			Produto p = this.gerenciadorProduto.buscarProduto(nomeProduto);

			try {
				this.gerenciadorAvaliacaoProduto.removerAvaliacoes(p);
			} catch (AvaliacaoInexistenteException e) {
			}

			this.gerenciadorProduto.removerProduto(nomeProduto);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}	
	}

	@Override
	public synchronized void descadastrarPromocao(long sessao, String nome) throws RemoteException, UsuarioSemPermissaoException, UsuarioNaoLogadoException, PromocaoInexistenteException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorPromocao.removerPromocao(nome);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}	
	}

	@Override
	public synchronized IteratorBidirecional<Filial> getFiliais() throws RemoteException, FilialInexistenteException {
		return this.gerenciadorFilial.getFiliais();
	}

	@Override
	public synchronized void mudarDescricaoPromocao(long sessao, Promocao promocao, String novaDescricao) throws RemoteException, UsuarioSemPermissaoException, UsuarioNaoLogadoException, PromocaoInexistenteException, PromocaoInvalidaException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorPromocao.mudarDescricaoPromocao(promocao, novaDescricao);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}	
	}

	@Override
	public synchronized void avaliarProduto(long sessao, AvaliacaoProduto avaliacao) throws UsuarioNaoLogadoException, UsuarioSemPermissaoException, AvaliacaoExistenteException, AvaliacaoInvalidaException, RemoteException {
		if(avaliacao != null){
			if(this.gerenciadorUsuario.estaLogado(sessao)){
				Usuario usuario = this.gerenciadorUsuario.getUsuarioLogado(sessao);

				if(usuario.equals(avaliacao.getUsuario())){
					this.gerenciadorAvaliacaoProduto.avaliarProduto(avaliacao);

					try {
						Produto p = this.gerenciadorProduto.buscarProduto(avaliacao.getProduto().getNome());
						Produto p2 = p;
						
						int media = 0;
						int n = 0;
						IteratorBidirecional<AvaliacaoProduto> avaliacoes = this.getAvaliacaoesProduto(p);
						while(avaliacoes.hasNext()){
							media = media + avaliacoes.next().getNota();
							n++;
						}
						
						if(n > 0){
							p2.setNota(media/n);
						}

						this.gerenciadorProduto.alterarDadosProduto(p2);
					} catch (ProdutoInexistenteException e) {
						// NAO vai acontecer
					} catch (ProdutoInvalidoException e) {
						// NAO vai acontecer
					} catch (ProdutoExistenteException e) {
						// NAO vai acontecer
					} catch (AvaliacaoInexistenteException e) {
						// NAO vai acontecer
					}

				} else {
					throw new UsuarioSemPermissaoException(usuario);
				}
			} else {
				throw new UsuarioNaoLogadoException();
			}
		} else {
			throw new IllegalArgumentException();
		}
	}

	@Override
	public synchronized AvaliacaoProduto buscarAvaliacaoProduto(long sessao, Produto produto) throws UsuarioNaoLogadoException, AvaliacaoInexistenteException, RemoteException {
		if(this.gerenciadorUsuario.estaLogado(sessao)){
			Usuario usuario = this.gerenciadorUsuario.getUsuarioLogado(sessao);
			return this.gerenciadorAvaliacaoProduto.buscarAvaliacaoProduto(usuario, produto);
		} else {
			throw new UsuarioNaoLogadoException();
		}
	}

	@Override
	public synchronized IteratorBidirecional<AvaliacaoProduto> getAvaliacaoesProduto(Produto produto) throws AvaliacaoInexistenteException, RemoteException {
		return this.gerenciadorAvaliacaoProduto.getAvaliacaoesProduto(produto);
	}

	@Override
	public synchronized IteratorBidirecional<AvaliacaoProduto> getAvaliacaoesUsuario(long sessao) throws UsuarioNaoLogadoException, AvaliacaoInexistenteException, RemoteException {
		if(this.gerenciadorUsuario.estaLogado(sessao)){
			Usuario usuario = this.gerenciadorUsuario.getUsuarioLogado(sessao);
			return this.gerenciadorAvaliacaoProduto.getAvaliacaoesUsuario(usuario);
		} else {
			throw new UsuarioNaoLogadoException();
		}
	}

	@Override
	public synchronized void removerAvaliacaoProduto(long sessao, Produto produto) throws UsuarioNaoLogadoException, AvaliacaoInexistenteException, RemoteException {
		if(this.gerenciadorUsuario.estaLogado(sessao)){
			Usuario usuario = this.gerenciadorUsuario.getUsuarioLogado(sessao);
			this.gerenciadorAvaliacaoProduto.removerAvaliacao(usuario, produto);
		} else {
			throw new UsuarioNaoLogadoException();
		}
	}

	@Override
	public synchronized void inserirLocacaoDomicilio(long sessao, Locacao locacao, Endereco endereco) throws RemoteException, LocacaoExistenteException, LocacaoInvalidaException, CopiaLocadaNoPeriodoException, UsuarioNaoLogadoException, UsuarioSemPermissaoException, CopiaReservadaNoPeriodoException, FilialNaoLogadaException {
		if(this.podeInserirLocacao(sessao, locacao)){
			String nomeFilial = locacao.getCopia().getFilial().getNome();
			if(this.gerenciadorFilial.estaLogada(nomeFilial)){

				try {
					try {
						String ipConfig = String.format("rmi://%s:1099/",InterfaceGeral.ip);
						InterfaceFilial servico = (InterfaceFilial) Naming.lookup(ipConfig + "InterfaceFilial_" + this.gerarNome(nomeFilial));

						new ThreadNotificar(servico, new Object[]{locacao, endereco}, "notificarLocacaoDomicilio").start();
					} catch (MalformedURLException e) {
						// NAO deve ocorrer
						e.printStackTrace();
					} catch (RemoteException e) {
						this.gerenciadorFilial.deslogarFilial(nomeFilial);
						throw new FilialNaoLogadaException(nomeFilial);
					} catch (NotBoundException e) {
						this.gerenciadorFilial.deslogarFilial(nomeFilial);
						throw new FilialNaoLogadaException(nomeFilial);
					}

				} catch (FilialInexistenteException e1) {
					// NAO deve ocorrer
					e1.printStackTrace();
				}

				this.inserirLocacao(sessao, locacao);
			} else {
				throw new FilialNaoLogadaException(nomeFilial);
			}
		} else {
			throw new UsuarioSemPermissaoException(this.gerenciadorUsuario.getUsuarioLogado(sessao));
		}
	}

	@Override
	public synchronized IteratorBidirecional<Filial> getFiliaisDisponiveis(Usuario user, Produto produto, Periodo p) throws FilialInexistenteException, ProdutoInexistenteException, RemoteException{
		try {
			IteratorBidirecional<Copia> copias = this.gerenciadorProduto.buscarProduto(produto.getNome()).getCopias();
			Copia copia;
			List<Filial> lista = new ArrayList<Filial>();
			IteratorBidirecional<Reserva> reservas;
			
			while(copias.hasNext()){
				copia = copias.next();
				
				if(copia.getFilial() != null){
					if(!lista.contains(copia.getFilial())){
						try {
							this.gerenciadorLocacao.buscarLocacao(copia);
						} catch (LocacaoInexistenteException e) {
							try {
								reservas = this.gerenciadorReserva.buscarReservas(copia);
								if(reservas.next().getCliente().getCpf() == user.getCpf()){
									if(!reservas.hasNext()){
										lista.add(copia.getFilial());
									}
								}
							} catch (ReservaInexistenteException e1) {
								lista.add(copia.getFilial());
							}
						}
					}
				}
			}
			
			IteratorBidirecional<Filial> it = new IteratorBidirecional<Filial>(lista.iterator());
			Filial filial;

			while(it.hasNext()){
				filial = it.next();
				
				if(this.gerenciadorFilial.estaLogada(filial.getNome())){
					try {
						try {
							String ipConfig = String.format("rmi://%s:1099/",InterfaceGeral.ip);
							Naming.lookup(ipConfig + "InterfaceFilial_" + this.gerarNome(filial.getNome()));
						} catch (MalformedURLException e) {
							// NAO deve ocorrer
							e.printStackTrace();
						} catch (RemoteException e) {
							it.remove();
							this.gerenciadorFilial.deslogarFilial(filial.getNome());
						} catch (NotBoundException e) {
							it.remove();
							this.gerenciadorFilial.deslogarFilial(filial.getNome());
						}
					} catch (FilialNaoLogadaException e1) {
						// NAO deve ocorrer
						e1.printStackTrace();
					}
				} else {
					it.remove();
				}
			}

			while(it.hasPrevious()){
				it.previous();
			}
			
			if(it.hasNext()){
				return it;
			} else{
				throw new FilialInexistenteException();
			}

		} catch (CopiaInexistenteException e) {
			throw new FilialInexistenteException();
		}
	}

	@Override
	public synchronized void mudarFilialDeCopia(long sessao, Produto produto, Copia copia, Filial filial) throws RemoteException, UsuarioNaoLogadoException, UsuarioSemPermissaoException, ProdutoInexistenteException, CopiaInexistenteException, FilialInvalidaException {
		Usuario transacao = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(transacao instanceof Administrador){
			this.gerenciadorProduto.mudarFilialDeCopia(copia, filial);
		} else {
			throw new UsuarioSemPermissaoException(transacao);
		}
	}

	@Override
	public synchronized ClassificacaoPreco buscarClassificacao(String descricao) throws ClassificacaoInexistenteException {
		return this.gerenciadorProduto.getClassificacaoPreco(descricao);
	}
	
	@Override
	public synchronized ClassificacaoPreco buscarClassificacao(long id) throws ClassificacaoInexistenteException, RemoteException {
		return this.gerenciadorProduto.getClassificacaoPreco(id);
	}

	@Override
	public synchronized void inserirClassificacao(long sessao,ClassificacaoPreco classificacao) throws UsuarioNaoLogadoException, ClassificacaoExistenteException, UsuarioSemPermissaoException {
		Usuario usuario = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(usuario != null && usuario instanceof Administrador){
			this.gerenciadorProduto.inserirClassificacao(classificacao);
		}else{
			throw new UsuarioSemPermissaoException(usuario);
		}
	}

	@Override
	public synchronized void removerClassificacao(long sessao, String descricao) throws ClassificacaoInexistenteException, UsuarioNaoLogadoException, UsuarioSemPermissaoException {
		Usuario usuario = this.gerenciadorUsuario.getUsuarioLogado(sessao);

		if(usuario != null && usuario instanceof Administrador){
			this.gerenciadorProduto.removerClassificacao(descricao);
		}else{
			throw new UsuarioSemPermissaoException(usuario);
		}
	}

	@Override
	public synchronized void atualizar(long sessao, ClassificacaoPreco classificacao) throws RemoteException, ClassificacaoInexistenteException,	UsuarioNaoLogadoException, PrecoInvalidoException, UsuarioSemPermissaoException {
		if(classificacao != null){
			Usuario usuario = this.gerenciadorUsuario.getUsuarioLogado(sessao);

			if(usuario != null && usuario instanceof Administrador){
				this.gerenciadorProduto.atualizarClassificacao(classificacao);
			}else{
				throw new UsuarioSemPermissaoException(usuario);
			}
		}else{
			throw new IllegalArgumentException();
		}
	}

	@Override
	public synchronized IteratorBidirecional<Produto> getProdutosRecomendados() throws RemoteException, ProdutoInexistenteException{
		return this.gerenciadorProduto.getProdutosRecomendados();
	}

	@Override
	public synchronized IteratorBidirecional<ClassificacaoPreco> getClassificacoes() throws RemoteException, ClassificacaoInexistenteException {
		return this.gerenciadorProduto.getClassificacoes();
	}
	
	@Override
	public synchronized void inserirLinkFoto(String nome, LinkFoto foto) throws LinkFotoExistenteException, ProdutoInexistenteException, RemoteException{
		this.gerenciadorProduto.inserirLinkFoto(nome, foto);
	}

	@Override
	public void atualizarPlano(long sessao, Plano atual) throws RemoteException, UsuarioSemPermissaoException, UsuarioNaoLogadoException, PlanoInexistenteException, PlanoInvalidoException {
		Usuario user = this.gerenciadorUsuario.getUsuarioLogado(sessao);
		if(user instanceof Administrador){
			this.gerenciadorPlano.atualizarPlano(atual);
		} else {
			throw new UsuarioNaoLogadoException();
		}
	}

}
