package testes;

import hibernate.GeradorTabelas;
import hibernate.HibernateTransaction;

import java.net.InetAddress;
import java.net.MalformedURLException;
import java.net.UnknownHostException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;

import negocio.exception.AvaliacaoExistenteException;
import negocio.exception.AvaliacaoInexistenteException;
import negocio.exception.ClassificacaoExistenteException;
import negocio.exception.ProdutoExistenteException;
import negocio.exception.ProdutoInexistenteException;
import negocio.exception.SenhaInvalidaException;
import negocio.exception.UsuarioInexistenteException;
import negocio.exception.UsuarioLogadoException;
import negocio.exception.UsuarioNaoLogadoException;
import negocio.exception.UsuarioSemPermissaoException;

import org.hibernate.Session;
import org.junit.Assert;
import org.junit.Test;

import dados.exception.AvaliacaoInvalidaException;
import dados.exception.CpfInvalidoException;
import dados.exception.EmailInvalidoException;
import dados.exception.NomeInvalidoException;
import dados.exception.PrecoInvalidoException;
import dados.exception.ProdutoInvalidoException;
import dados.produto.AvaliacaoProduto;
import dados.produto.ClassificacaoPreco;
import dados.produto.ClassificacaoPrecoInvalida;
import dados.produto.Filme;
import dados.produto.Produto;
import dados.usuario.Administrador;
import dados.usuario.Usuario;

import servicos.InterfaceGeral;
import servicos.InterfaceWebBD;
import util.IteratorBidirecional;

/**
 * Esta classe realiza todos os procedimentos de teste relacionados
 * ao gerenciador de avaliaes de produto. Eventualmente pode utilizar outros gerenciadores
 * como suporte para testar funcionalidades relacionadas. <br><br>
 * 
 *  utilizada a verso do JUnit 4, portanto no precisa que seja estendida
 * de TestCase.
 * @author Lais Sousa
 *
 */
public class AvaliacaoProdutoTest {

	private static InterfaceWebBD interfaceWebBD;
	
	/**
	 * Limpa o BD e insere o Administrador do sistema
	 */
	@Test
	public void inicializacao() {
		GeradorTabelas.limparBD();
		
		try {
			String ipConfig = String.format("rmi://%s:1099/",InterfaceGeral.ip);
			AvaliacaoProdutoTest.interfaceWebBD = (InterfaceWebBD) Naming.lookup(ipConfig +	"InterfaceWebBD");
		} catch (MalformedURLException e1) {
			Assert.assertTrue(false);
		} catch (RemoteException e1) {
			Assert.assertTrue(false);
		} catch (NotBoundException e1) {
			Assert.assertTrue(false);
		}
		
		Administrador admin = null;
		
		try {
			admin = new Administrador(Long.parseLong("05497966497"), "password", "admin", "teste@teste.com");
		} catch (NumberFormatException e) {
		} catch (NomeInvalidoException e) {
		} catch (SenhaInvalidaException e) {
		} catch (CpfInvalidoException e) {
		} catch (EmailInvalidoException e) {
		}
		
		HibernateTransaction busca = new HibernateTransaction();
		busca.openSessionBegin();
		Session sessao = busca.getSession();

		sessao.save(admin);

		busca.closeSessionCommit();

		try {
			long s = AvaliacaoProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			AvaliacaoProdutoTest.interfaceWebBD.inserirClassificacao(s, new ClassificacaoPreco("NORMAL", 5.0));
			AvaliacaoProdutoTest.interfaceWebBD.inserirClassificacao(s, new ClassificacaoPreco("LANAMENTO", 5.0));
			AvaliacaoProdutoTest.interfaceWebBD.inserirClassificacao(s, new ClassificacaoPreco("LANAMENTO 24 HORAS", 5.0));
			AvaliacaoProdutoTest.interfaceWebBD.deslogar(s);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (ClassificacaoExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (PrecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (ClassificacaoPrecoInvalida e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-14-1 ----
	 * Este teste foi feito para testar a avaliao de um produto por um usurio. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - O filme Matrix no deve estar cadastrado. <br>
	 */
	@Test
	public void pt_14_1(){
		try {
			long sessao = AvaliacaoProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			Usuario usuario = AvaliacaoProdutoTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("05497966497"));
			Produto produto = new Filme("Matrix - Filme", "fico cientifica", "14 anos", "mto bom!!!", "nao se sabe", "www.link.com.br", "nao se sabe", "irmaos sei que lah", new ClassificacaoPreco("NORMAL", 5.0), 1999, 200);
			AvaliacaoProdutoTest.interfaceWebBD.cadastrarProduto(sessao, produto);

			AvaliacaoProduto avaliacao = new AvaliacaoProduto(10, true, "mto mto mto bom!!!!", usuario, produto);
			AvaliacaoProdutoTest.interfaceWebBD.avaliarProduto(sessao, avaliacao);
			
			avaliacao = null;
			avaliacao = AvaliacaoProdutoTest.interfaceWebBD.buscarAvaliacaoProduto(sessao, produto);
			Assert.assertNotNull(avaliacao);
			
			IteratorBidirecional<AvaliacaoProduto> it = null;
			it = AvaliacaoProdutoTest.interfaceWebBD.getAvaliacaoesProduto(produto);
			Assert.assertNotNull(it);
			Assert.assertTrue(it.hasNext());
			Assert.assertEquals(it.next(), avaliacao);
			
			it = null;
			it = AvaliacaoProdutoTest.interfaceWebBD.getAvaliacaoesUsuario(sessao);
			Assert.assertNotNull(it);
			Assert.assertTrue(it.hasNext());
			Assert.assertEquals(it.next(), avaliacao);
			
			AvaliacaoProdutoTest.interfaceWebBD.removerAvaliacaoProduto(sessao, produto);
			AvaliacaoProdutoTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			e.printStackTrace();
			System.out.println(e.getMessage());
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (AvaliacaoInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (ProdutoExistenteException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (AvaliacaoExistenteException e) {
			Assert.assertTrue(false);
		} catch (AvaliacaoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (PrecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (ClassificacaoPrecoInvalida e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-14-2 ----
	 * Este teste foi feito para testar a avaliao de um produto por
	 * um usurio mais de uma vez. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - O filme Matrix deve estar cadastrado. <br>
	 */
	@Test
	public void pt_14_2(){
		long sessao = 0;
		Produto produto = null;
		
		try {
			sessao = AvaliacaoProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			
			Usuario usuario = AvaliacaoProdutoTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("05497966497"));
			produto = AvaliacaoProdutoTest.interfaceWebBD.buscarProduto("Matrix - Filme");

			AvaliacaoProduto avaliacao = new AvaliacaoProduto(5, false, "mto mto mto ruim!!!!", usuario, produto);
			AvaliacaoProdutoTest.interfaceWebBD.avaliarProduto(sessao, avaliacao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (AvaliacaoInvalidaException e) {
			Assert.assertTrue(false);
		} catch (AvaliacaoExistenteException e) {
		}
		
		try {
			AvaliacaoProdutoTest.interfaceWebBD.descadastrarProduto(sessao, produto.getNome());
			AvaliacaoProdutoTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		}
	}
}
