package testes;

import hibernate.GeradorTabelas;
import hibernate.HibernateTransaction;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.Iterator;

import negocio.exception.CopiaExistenteException;
import negocio.exception.CopiaInexistenteException;
import negocio.exception.CopiaLocadaNoPeriodoException;
import negocio.exception.CopiaReservadaNoPeriodoException;
import negocio.exception.FilialExistenteException;
import negocio.exception.FilialInexistenteException;
import negocio.exception.LocacaoExistenteException;
import negocio.exception.PlanoExistenteException;
import negocio.exception.ProdutoInexistenteException;
import negocio.exception.SenhaInvalidaException;
import negocio.exception.UsuarioExistenteException;
import negocio.exception.UsuarioInexistenteException;
import negocio.exception.UsuarioLogadoException;
import negocio.exception.UsuarioNaoLogadoException;
import negocio.exception.UsuarioSemPermissaoException;

import org.hibernate.Session;
import org.junit.Assert;
import org.junit.Test;

import dados.exception.CopiaInvalidaException;
import dados.exception.CpfInvalidoException;
import dados.exception.EmailInvalidoException;
import dados.exception.EnderecoInvalidoException;
import dados.exception.FilialInvalidaException;
import dados.exception.LinkFotoInvalidoException;
import dados.exception.LocacaoInvalidaException;
import dados.exception.NomeInvalidoException;
import dados.exception.PeriodoInvalidoException;
import dados.exception.PlanoInvalidoException;
import dados.exception.PrecoInvalidoException;
import dados.exception.ProdutoInvalidoException;
import dados.exception.TelefoneInvalidoException;
import dados.filial.Endereco;
import dados.filial.Filial;
import dados.locacao.Copia;
import dados.locacao.Locacao;
import dados.locacao.Periodo;
import dados.produto.ClassificacaoPreco;
import dados.produto.ClassificacaoPrecoInvalida;
import dados.produto.Filme;
import dados.produto.LinkFoto;
import dados.produto.Produto;
import dados.produto.TipoLinkFoto;
import dados.usuario.Administrador;
import dados.usuario.Cliente;
import dados.usuario.Plano;
import dados.usuario.Telefone;

import servicos.InterfaceWebBD;

/**
 * Esta classe realiza todos os procedimentos de teste relacionados
 * ao gerenciador de filiais. Eventualmente pode utilizar outros gerenciadores
 * como suporte para testar funcionalidades relacionadas. <br><br>
 * 
 *  utilizada a verso do JUnit 4, portanto no precisa que seja estendida
 * de TestCase.
 * @author Lais Sousa
 *
 */
public class FilialTest {

	private static InterfaceWebBD interfaceWebBD;
	
	/**
	 * Limpa o BD e insere o Administrador do sistema
	 */
	@Test
	public void inicializacao(){
		GeradorTabelas.limparBD();
		
		try {
			String ipConfig = String.format("rmi://%s:1099/", InterfaceWebBD.ip);
			FilialTest.interfaceWebBD = (InterfaceWebBD) Naming.lookup(ipConfig +	"InterfaceWebBD");
		} catch (MalformedURLException e1) {
			Assert.assertTrue(false);
		} catch (RemoteException e1) {
			Assert.assertTrue(false);
		} catch (NotBoundException e1) {
			Assert.assertTrue(false);
		}
		
		Administrador admin = null;
		Filial f1 = null, f2 = null, f3 = null;
		Produto p = null;
		Copia c1 = null, c2 = null, c3 = null;
		ClassificacaoPreco cs = null;
		
		try {
			cs = new ClassificacaoPreco("abc", 10.0);
			admin = new Administrador(Long.parseLong("05497966497"), "password", "admin", "videosystem.locadora@gmail.com");
			
			f1 = new Filial("Filial 1", new Telefone(10,10000010), new Endereco("a", "b", "c", "d", null, 21, 111111));
			f2 = new Filial("Filial 2", new Telefone(10,10000010), new Endereco("a", "b", "c", "d", null, 21, 111111));
			f3 = new Filial("Filial 3", new Telefone(10,10000010), new Endereco("a", "b", "c", "d", null, 21, 111111));
			p = new Filme("Teste","a","a","a","a","a","a","a", cs,2,20);
			c1 = new Copia(1,f1,p);
			c2 = new Copia(2,f2,p);
			c3 = new Copia(3,f3,p);
		} catch (NumberFormatException e) {
			e.printStackTrace();
		} catch (FilialInvalidaException e) {
			e.printStackTrace();
		} catch (TelefoneInvalidoException e) {
			e.printStackTrace();
		} catch (EnderecoInvalidoException e) {
			e.printStackTrace();
		} catch (ProdutoInvalidoException e) {
			e.printStackTrace();
		} catch (PrecoInvalidoException e) {
			e.printStackTrace();
		} catch (CopiaInvalidaException e) {
			e.printStackTrace();
		} catch (NomeInvalidoException e) {
		} catch (SenhaInvalidaException e) {
		} catch (CpfInvalidoException e) {
		} catch (EmailInvalidoException e) {
		} catch (ClassificacaoPrecoInvalida e) {
			e.printStackTrace();
		}
		
		HibernateTransaction busca = new HibernateTransaction();
		busca.openSessionBegin();
		Session sessao = busca.getSession();

		sessao.save(admin);
		sessao.save(f1);
		sessao.save(f2);
		sessao.save(f3);
		sessao.save(cs);
		sessao.save(p);
		sessao.save(c1);
		sessao.save(c2);
		sessao.save(c3);
		
		try {
			p.inserirCopia(c1);
			p.inserirCopia(c2);
			p.inserirCopia(c3);
			sessao.update(p);
		} catch (CopiaExistenteException e) {
			e.printStackTrace();
		}

		busca.closeSessionCommit();
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-11-1 ----
	 * Este teste foi feito para testar a verificao de filiais
	 * disponveis. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - O produto "Teste" deve estar cadastrado. <br>
	 * <b> - As Filiais "Filial 1", "Filial 2" e "Filial 3" devem estar cadastradas. <br>
	 * <b> - As cpias 1, 2 e 3 do produto "Teste" devem estar cadastradas e sem locao. <br>
	 */
	@Test
	public void pt_11_1(){
		long sessao = 0;
		try {
			sessao = FilialTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			Produto p = FilialTest.interfaceWebBD.buscarProduto("Teste");
			Iterator<Copia> i = p.getCopias();
			
			Plano p1 = new Plano(10.0,"abc","def",40, new LinkFoto(TipoLinkFoto.NORMAL, "lalalala"));
			Cliente cliente = new Cliente(Long.parseLong("08902507408"),"abcdefgh","aaa","videosystem.locadora@gmail.com", p1,new Endereco("a","b","c","d","e",2,3));
			FilialTest.interfaceWebBD.cadastrarPlano(sessao, p1);
			FilialTest.interfaceWebBD.cadastrarUsuario(sessao, cliente);
			
			Filial fErrada = null;
			if(i.hasNext()){
				Copia c = i.next();
				fErrada = c.getFilial();
				FilialTest.interfaceWebBD.inserirLocacao(sessao, new Locacao((Cliente)FilialTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08902507408")), c, new Periodo(new GregorianCalendar(2008, Calendar.OCTOBER, 1), new GregorianCalendar(2008, Calendar.OCTOBER, 15))));
			}
			
			Iterator<Filial> it = FilialTest.interfaceWebBD.getFiliaisDisponiveis(cliente, p, new Periodo(new GregorianCalendar(2008, Calendar.OCTOBER, 9), new GregorianCalendar(2008, Calendar.OCTOBER, 10)));
			Assert.assertNotNull(it);
			Assert.assertTrue(it.hasNext());
			Filial f = it.next();
			Assert.assertNotNull(f);
			Assert.assertNotSame(f, fErrada);
			
			Assert.assertTrue(it.hasNext());
			f = it.next();
			Assert.assertNotNull(f);
			Assert.assertNotSame(f, fErrada);

			Assert.assertEquals(false, it.hasNext());
			FilialTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(true);
		} catch (PeriodoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (LocacaoExistenteException e) {
			Assert.assertTrue(false);
		} catch (LocacaoInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (CopiaLocadaNoPeriodoException e) {
			Assert.assertTrue(false);
		} catch (CopiaReservadaNoPeriodoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (PlanoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (PlanoExistenteException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		} catch (LinkFotoInvalidoException e) {
			Assert.assertTrue(false);
		}
		
		
		try {
			FilialTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-11-2 ----
	 * Este teste foi feito para testar a verificao de filiais
	 * disponveis quando nenhuma filial possui copias disponveis. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - O produto "Teste" deve estar cadastrado. <br>
	 * <b> - As Filiais "Filial 1", "Filial 2" e "Filial 3" devem estar cadastradas. <br>
	 * <b> - As cpias 1, 2 e 3 do produto "Teste" devem estar cadastradas. <br>
	 */
	@Test
	public void pt_11_2(){
		long sessao = 0;
		try {
			sessao = FilialTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			Produto p = FilialTest.interfaceWebBD.buscarProduto("Teste");
			
			Cliente cliente = (Cliente)FilialTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08902507408"));
			
			FilialTest.interfaceWebBD.getFiliaisDisponiveis(cliente, p, new Periodo(new GregorianCalendar(2008, Calendar.JULY, 9), new GregorianCalendar(2008, Calendar.JULY, 20)));
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			try {
				FilialTest.interfaceWebBD.deslogar(sessao);
			} catch (RemoteException e1) {
				Assert.assertTrue(false);
			} catch (UsuarioNaoLogadoException e1) {
				Assert.assertTrue(false);
			}
		} catch (PeriodoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-24-1 ----
	 * Este teste foi feito para testar o cadastro de uma filial com sucesso. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - A Filial "Filial Boa Viagem" no deve estar cadastrada. <br>
	 */
	@Test
	public void pt_24_1(){
		try {
			long sessao = FilialTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");

			Endereco e = new Endereco("Av. Boa Viagem", "PE", "Recife", "Boa Viagem", null, 881, 52041060);
			Telefone t = new Telefone(81, 99716907);
			Filial filial = new Filial("Filial Boa Viagem", t, e);

			FilialTest.interfaceWebBD.cadastrarFilial(sessao, filial);
			FilialTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e1) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e1) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e1) {
			Assert.assertTrue(false);
		} catch (FilialExistenteException e1) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e1) {
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (TelefoneInvalidoException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-24-2 ----
	 * Este teste foi feito para testar o cadastro de uma filial 
	 * passando-se dados incorretos. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 */
	@Test
	public void pt_24_2(){
		long sessao = 0;
		try {
			sessao = FilialTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			FilialTest.interfaceWebBD.cadastrarFilial(sessao, new Filial("Filial", null, null));
			Assert.assertTrue(false);
		} catch (NumberFormatException e2) {
			Assert.assertTrue(false);
		} catch (RemoteException e2) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e2) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e2) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e2) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e) {
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (FilialExistenteException e) {
			Assert.assertTrue(false);
		}

		try {
			FilialTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e1) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e1) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-24-3 ----
	 * Este teste foi feito para testar o cadastro de uma filial j existente no sistema. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - A Filial "Filial Boa Viagem" deve estar cadastrada. <br>
	 */
	@Test
	public void pt_24_3(){
		long sessao = 0;

		try {
			sessao = FilialTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");

			Endereco e;
			e = new Endereco("errado", "errado", "errado", "errado", null, 881, 52041060);
			Telefone t = new Telefone(81, 99716907);
			Filial filial = new Filial("Filial Boa Viagem", t, e);

			FilialTest.interfaceWebBD.cadastrarFilial(sessao, filial);
			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e1) {
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (TelefoneInvalidoException e) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (FilialExistenteException e) {
		}

		try {
			FilialTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-25-1 ----
	 * Este teste foi feito para testar a modificao do cadastro de uma filial com sucesso. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - A Filial "Filial Boa Viagem" deve estar cadastrada. <br>
	 */
	@Test
	public void pt_25_1(){
		try {
			long sessao = FilialTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");

			Endereco e = new Endereco("Av. Boa Viagem", "PE", "Recife", "Boa Viagem", "loja", 881, 52041060);
			Telefone t = new Telefone(81, 99716907);
			Filial dados = new Filial("Filial Boa Viagem", t, e);

			FilialTest.interfaceWebBD.atualizarFilial(sessao, dados);
			FilialTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e1) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e1) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e1) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e1) {
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (TelefoneInvalidoException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-25-2 ----
	 * Este teste foi feito para testar a modificao do cadastro de uma filial
	 * passando-se dados incorretos. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - A Filial "Filial Boa Viagem" deve estar cadastrada. <br>
	 */
	@Test
	public void pt_25_2(){
		long sessao = 0;
		
		try {
			sessao = FilialTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			FilialTest.interfaceWebBD.atualizarFilial(sessao, new Filial("Filial Boa Viagem", null, null));
		} catch (RemoteException e1) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e1) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e1) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e1) {
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		}
		
		try {
			FilialTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-08 ----
	 * Este teste foi feito para testar a recuperao de informaes de uma
	 * filial cadastrada. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - A Filial "Filial Boa Viagem" deve estar cadastrada. <br>
	 */
	@Test
	public void pt_08(){
		try {
			Filial filial = FilialTest.interfaceWebBD.buscarFilial("Filial Boa Viagem");
			Assert.assertNotNull(filial);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-26-1 ----
	 * Este teste foi feito para testar a remoo do cadastro de uma filial com sucesso. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - A Filial "Filial Boa Viagem" deve estar cadastrada. <br>
	 */
	@Test
	public void pt_26_1(){
		try {
			long sessao = FilialTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			FilialTest.interfaceWebBD.descadastrarFilial(sessao, "Filial Boa Viagem");
			FilialTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-26-1 ----
	 * Este teste foi feito para testar a remoo do cadastro de uma filial inexistente. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - A Filial "Filial Boa Viagem" no deve estar cadastrada. <br>
	 */
	@Test
	public void pt_26_2(){
		long sessao = 0;
		
		try {
			sessao = FilialTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			FilialTest.interfaceWebBD.descadastrarFilial(sessao, "Filial Boa Viagem");
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
		}
		
		try {
			FilialTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}

}
