package testes;

import hibernate.GeradorTabelas;
import hibernate.HibernateTransaction;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;
import java.util.Iterator;

import negocio.exception.PlanoExistenteException;
import negocio.exception.PlanoInexistenteException;
import negocio.exception.SenhaInvalidaException;
import negocio.exception.UsuarioInexistenteException;
import negocio.exception.UsuarioLogadoException;
import negocio.exception.UsuarioNaoLogadoException;
import negocio.exception.UsuarioSemPermissaoException;

import org.hibernate.Session;
import org.junit.Assert;
import org.junit.Test;

import dados.exception.CpfInvalidoException;
import dados.exception.EmailInvalidoException;
import dados.exception.LinkFotoInvalidoException;
import dados.exception.NomeInvalidoException;
import dados.exception.PlanoInvalidoException;
import dados.produto.LinkFoto;
import dados.produto.TipoLinkFoto;
import dados.usuario.Administrador;
import dados.usuario.Plano;

import servicos.InterfaceWebBD;

/**
 * Esta classe realiza todos os procedimentos de teste relacionados
 * ao gerenciador de planos. Eventualmente pode utilizar outros gerenciadores
 * como suporte para testar funcionalidades de dados relacionados. <br><br>
 * 
 *  utilizada a verso do JUnit 4, portanto no precisa que seja estendida
 * de TestCase.
 * @author Lais Sousa
 *
 */
public class PlanoTest {

	private static InterfaceWebBD interfaceWebBD;

	/**
	 * Limpa o BD e insere o Administrador do sistema
	 */
	@Test
	public void inicializacao(){
		GeradorTabelas.limparBD();
		
		try {
			String ipConfig = String.format("rmi://%s:1099/",InterfaceWebBD.ip);
			PlanoTest.interfaceWebBD = (InterfaceWebBD) Naming.lookup(ipConfig +	"InterfaceWebBD");
		} catch (MalformedURLException e1) {
			Assert.assertTrue(false);
		} catch (RemoteException e1) {
			Assert.assertTrue(false);
		} catch (NotBoundException e1) {
			Assert.assertTrue(false);
		}
		
		Administrador admin = null;
		
		try {
			admin = new Administrador(Long.parseLong("05497966497"), "password", "admin", "teste@teste.com");
		} catch (NumberFormatException e) {
		} catch (NomeInvalidoException e) {
		} catch (SenhaInvalidaException e) {
		} catch (CpfInvalidoException e) {
		} catch (EmailInvalidoException e) {
		}
		
		HibernateTransaction busca = new HibernateTransaction();
		busca.openSessionBegin();
		Session sessao = busca.getSession();

		sessao.save(admin);

		busca.closeSessionCommit();
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-13-1 ----
	 * Este teste foi feito para testar a busca pelos planos da locadora. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 */
	@Test
	public void pt_13_1(){
		try {
			long sessao = PlanoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			
			Plano p[] = new Plano[5];
			
			for(int i = 0; i < 5; i++){
				p[i] = new Plano(100.00*i, String.format("Plano %d", i), String.format("plano numero %d", i), i*10,new LinkFoto(TipoLinkFoto.NORMAL, "lalal"));
				PlanoTest.interfaceWebBD.cadastrarPlano(sessao, p[i]);
			}
			
			Iterator<Plano> it = PlanoTest.interfaceWebBD.getPlanos();
			Assert.assertNotNull(it);
			boolean achou;
			Plano plano = null;
			
			while(it.hasNext()){
				achou = false;
				plano = it.next();
				
				for(int i = 0; i < 5 && !achou; i++){
					if(plano.equals(p[i])){
						achou = true;
					}
				}
				
				Assert.assertTrue(achou);
			}
			
			PlanoTest.interfaceWebBD.descadastrarPlano(sessao, plano.getNome());
			
			PlanoTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (PlanoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (PlanoExistenteException e) {
			Assert.assertTrue(false);
		} catch (PlanoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (LinkFotoInvalidoException e) {
			Assert.assertTrue(false);
		}
	}
}
