package testes;

import hibernate.GeradorTabelas;
import hibernate.HibernateTransaction;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;

import java.util.GregorianCalendar;
import java.util.Iterator;

import negocio.exception.ClassificacaoExistenteException;
import negocio.exception.ClassificacaoInexistenteException;
import negocio.exception.CopiaExistenteException;
import negocio.exception.CopiaInexistenteException;
import negocio.exception.CopiaLocadaNoPeriodoException;
import negocio.exception.CopiaReservadaNoPeriodoException;
import negocio.exception.FilialExistenteException;
import negocio.exception.FilialInexistenteException;
import negocio.exception.LocacaoExistenteException;
import negocio.exception.LocacaoInexistenteException;
import negocio.exception.PlanoExistenteException;
import negocio.exception.ProdutoExistenteException;
import negocio.exception.ProdutoInexistenteException;
import negocio.exception.SenhaInvalidaException;
import negocio.exception.UsuarioExistenteException;
import negocio.exception.UsuarioInexistenteException;
import negocio.exception.UsuarioLogadoException;
import negocio.exception.UsuarioNaoLogadoException;
import negocio.exception.UsuarioSemPermissaoException;

import org.hibernate.Session;
import org.junit.Assert;
import org.junit.Test;

import dados.exception.CopiaInvalidaException;
import dados.exception.CpfInvalidoException;
import dados.exception.EmailInvalidoException;
import dados.exception.EnderecoInvalidoException;
import dados.exception.FilialInvalidaException;
import dados.exception.LinkFotoInvalidoException;
import dados.exception.LocacaoInvalidaException;
import dados.exception.NomeInvalidoException;
import dados.exception.PeriodoInvalidoException;
import dados.exception.PlanoInvalidoException;
import dados.exception.PrecoInvalidoException;
import dados.exception.ProdutoInvalidoException;
import dados.exception.TelefoneInvalidoException;
import dados.filial.Endereco;
import dados.filial.Filial;
import dados.locacao.Copia;
import dados.locacao.Locacao;
import dados.locacao.Periodo;
import dados.produto.ClassificacaoPreco;
import dados.produto.ClassificacaoPrecoInvalida;
import dados.produto.CriterioBusca;
import dados.produto.Filme;
import dados.produto.LinkFoto;
import dados.produto.Produto;
import dados.produto.TipoLinkFoto;
import dados.produto.TipoProduto;
import dados.usuario.Administrador;
import dados.usuario.Cliente;
import dados.usuario.Funcionario;
import dados.usuario.Plano;
import dados.usuario.Telefone;

import servicos.InterfaceWebBD;

/**
 * Esta classe realiza todos os procedimentos de teste relacionados
 * ao gerenciador de produtos. Eventualmente pode utilizar outros gerenciadores
 * como suporte para testar outras funcionalidades relacionadas aos mesmos. <br><br>
 * 
 *  utilizada a verso do JUnit 4, portanto no precisa que seja estendida
 * de TestCase.
 * @author Lais Sousa
 *
 */
public class ProdutoTest {

	private static InterfaceWebBD interfaceWebBD;

	/**
	 * Limpa o BD e insere o Administrador do sistema
	 */
	@Test
	public void inicializacao(){
		GeradorTabelas.limparBD();
		
		try {
			String ipConfig = String.format("rmi://%s:1099/",InterfaceWebBD.ip);
			ProdutoTest.interfaceWebBD = (InterfaceWebBD) Naming.lookup(ipConfig +	"InterfaceWebBD");
		} catch (MalformedURLException e1) {
			Assert.assertTrue(false);
		} catch (RemoteException e1) {
			Assert.assertTrue(false);
		} catch (NotBoundException e1) {
			Assert.assertTrue(false);
		}
		
		Administrador admin = null;

		try {
			admin = new Administrador(Long.parseLong("05497966497"), "password", "admin", "teste@teste.com");
		} catch (NumberFormatException e) {
		} catch (NomeInvalidoException e) {
		} catch (SenhaInvalidaException e) {
		} catch (CpfInvalidoException e) {
		} catch (EmailInvalidoException e) {
		}

		HibernateTransaction busca = new HibernateTransaction();
		busca.openSessionBegin();
		Session sessao = busca.getSession();

		sessao.save(admin);

		busca.closeSessionCommit();
		
		try {
			long s = ProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			ProdutoTest.interfaceWebBD.inserirClassificacao(s, new ClassificacaoPreco("NORMAL", 5.0));
			ProdutoTest.interfaceWebBD.inserirClassificacao(s, new ClassificacaoPreco("LANAMENTO", 5.0));
			ProdutoTest.interfaceWebBD.inserirClassificacao(s, new ClassificacaoPreco("LANAMENTO 24 HORAS", 5.0));
			ProdutoTest.interfaceWebBD.deslogar(s);
		} catch (NumberFormatException e) {
			e.printStackTrace();
		} catch (RemoteException e) {
			e.printStackTrace();
		} catch (UsuarioLogadoException e) {
			e.printStackTrace();
		} catch (UsuarioInexistenteException e) {
			e.printStackTrace();
		} catch (SenhaInvalidaException e) {
			e.printStackTrace();
		} catch (UsuarioNaoLogadoException e) {
			e.printStackTrace();
		} catch (ClassificacaoExistenteException e) {
			e.printStackTrace();
		} catch (UsuarioSemPermissaoException e) {
			e.printStackTrace();
		} catch (PrecoInvalidoException e) {
			e.printStackTrace();
		} catch (ClassificacaoPrecoInvalida e) {
			e.printStackTrace();
		}

	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-07-1 ----
	 * Este teste foi feito para testar a busca de informaes sobre um produto existente. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 */
	@Test
	public void pt_07_1(){
		try {
			long sessao = ProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			Produto produto = new Filme("Matrix - Filme", "Fico Cientfica", "14 anos", "mto bom!!!", "nao se sabe", "www.link.com.br", "nao se sabe", "irmaos sei que lah", ProdutoTest.interfaceWebBD.buscarClassificacao("NORMAL"), 1999, 200);

			ProdutoTest.interfaceWebBD.cadastrarProduto(sessao, produto);
			produto = null;

			produto = ProdutoTest.interfaceWebBD.buscarProduto("Matrix - Filme");
			Assert.assertNotNull(produto);
			produto = null;

			Iterator<Produto> it = ProdutoTest.interfaceWebBD.buscarProdutoRestricoes(new CriterioBusca(TipoProduto.FILME, null, "Fico Cientfica", null, "NORMAL", null, null));
			Assert.assertTrue(it.hasNext());
			it = null;

			it = ProdutoTest.interfaceWebBD.buscarProdutoTipo(TipoProduto.FILME);
			Assert.assertTrue(it.hasNext());
			ProdutoTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (ProdutoExistenteException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (ClassificacaoInexistenteException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-07-2 ----
	 * Este teste foi feito para testar a busca de informaes sobre
	 * um produto inexistente. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O produto "Produto Inexistente" no deve estar cadastrado. <br>
	 */
	@Test
	public void pt_07_2(){
		try {
			ProdutoTest.interfaceWebBD.buscarProduto("Produto Inexistente");
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
		}

		try {
			ProdutoTest.interfaceWebBD.buscarProdutoRestricoes(new CriterioBusca(null, "Produto Inexistente", null, null, null, null, null));
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-09-1 ----
	 * Este teste foi feito para testar a disponibilidade de cpias
	 * de um produto com cpias. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - O produto "Matrix - Filme" deve estar cadastrado. <br>
	 * <b> - O produto "Matrix - Filme" no deve ter cpia com nmero 50. <br>
	 * <b> - A filial "Filial Boa Viagem" deve estar cadastrada. <br>
	 */
	@Test
	public void pt_09_1(){
		try {
			long sessao = ProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			ProdutoTest.interfaceWebBD.cadastrarFilial(sessao, new Filial("Filial Boa Viagem",new Telefone(81, 55555555), new Endereco("Av. Boa Viagem", "PE", "Recife", "Boa Viagem", null, 50, 52041060)));
			Copia c = new Copia(50, ProdutoTest.interfaceWebBD.buscarFilial("Filial Boa Viagem"), ProdutoTest.interfaceWebBD.buscarProduto("Matrix - Filme"));
			ProdutoTest.interfaceWebBD.cadastrarCopia(sessao, c);
			Iterator<Copia> it = ProdutoTest.interfaceWebBD.buscarProduto("Matrix - Filme").getCopias();

			Assert.assertNotNull(it);
			Assert.assertTrue(it.hasNext());
			Assert.assertEquals(it.next(), c);

			ProdutoTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (CopiaExistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaInexistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialExistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e) {
			Assert.assertTrue(false);
		} catch (TelefoneInvalidoException e) {
			e.printStackTrace();
			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-09-2 ----
	 * Este teste foi feito para testar a disponibilidade de cpias
	 * de um produto existente. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - O produto "Matrix - Filme" deve estar cadastrado. <br>
	 * <b> - O produto "Matrix - Filme" deve ter somente a cpia com nmero 50. <br>
	 * <b> - A filial "Filial Boa Viagem" deve estar cadastrada. <br>
	 */
	@Test
	public void pt_09_2(){
		long sessao = 0;
		try {
			sessao = ProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			ProdutoTest.interfaceWebBD.descadastrarCopia(sessao, "Matrix - Filme", 50);
			ProdutoTest.interfaceWebBD.buscarProduto("Matrix - Filme").getCopias();
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (CopiaInexistenteException e) {
			try {
				ProdutoTest.interfaceWebBD.deslogar(sessao);
			} catch (RemoteException e1) {
				Assert.assertTrue(false);
			} catch (UsuarioNaoLogadoException e1) {
				Assert.assertTrue(false);
			}
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-10-1 ----
	 * Este teste foi feito para lista produtos por restrio
	 * quando se espera algum resultado na lista de produtos. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - O produto "Matrix - Filme" deve estar cadastrado. <br>
	 * <b> - O produto "Filme Fico 1" no deve estar cadastrado. <br>
	 * <b> - O produto "Filme Fico 2" no deve estar cadastrado. <br>
	 * <b> - O produto "Filme Fico 3" no deve estar cadastrado. <br>
	 */
	@Test
	public void pt_10_1(){
		long sessao = 0;
		try {
			Produto filme1 = new Filme("Filme Fico 1", "Fico Cientfica","55 anos", "Nenhuma", "Falida", "www.nada.com.br", "Diretor ningum", "Autor algum", ProdutoTest.interfaceWebBD.buscarClassificacao("NORMAL"),2000, 60);
			Produto filme2 = new Filme("Filme Fico 2", "Fico Cientfica","30 anos", "Nada", "Falida Empresa", "www.nada2.com.br", "Diretor ningum2", "Autor algum2", ProdutoTest.interfaceWebBD.buscarClassificacao("LANAMENTO"),2004, 60);
			Produto filme3 = new Filme("Filme Fico 3", "Fico Cientfica","55 anos", "Nenhuma", "Falida", "www.nada.com.br", "Diretor ningum", "Autor algum", ProdutoTest.interfaceWebBD.buscarClassificacao("LANAMENTO 24 HORAS"),2000, 60);
			sessao = ProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			ProdutoTest.interfaceWebBD.cadastrarProduto(sessao, filme1);
			ProdutoTest.interfaceWebBD.cadastrarProduto(sessao, filme2);
			ProdutoTest.interfaceWebBD.cadastrarProduto(sessao, filme3);

			Iterator<Produto> it = ProdutoTest.interfaceWebBD.buscarProdutoRestricoes(new CriterioBusca(TipoProduto.FILME, null, null, null, "NORMAL", null, null));

			Assert.assertNotNull(it);
			Assert.assertTrue(it.hasNext());
			Produto p = it.next();
			Assert.assertNotNull(p);
			Assert.assertTrue(p instanceof Filme);
			Assert.assertTrue(((Filme) p).getNome().equals("Matrix - Filme") || ((Filme) p).getNome().equals("Filme Fico 1"));

			Assert.assertTrue(it.hasNext());
			p = it.next();
			Assert.assertNotNull(p);
			Assert.assertTrue(p instanceof Filme);
			Assert.assertTrue(((Filme) p).getNome().equals("Matrix - Filme") || ((Filme) p).getNome().equals("Filme Fico 1"));

			Assert.assertEquals(false, it.hasNext());

			it = ProdutoTest.interfaceWebBD.buscarProdutoRestricoes(new CriterioBusca(TipoProduto.FILME, null, null, null, "LANAMENTO", null, null));

			Assert.assertNotNull(it);
			Assert.assertTrue(it.hasNext());
			p = it.next();
			Assert.assertNotNull(p);
			Assert.assertTrue(p instanceof Filme);
			Assert.assertTrue(((Filme) p).getNome().equals("Filme Fico 2"));

			Assert.assertEquals(false, it.hasNext());

			ProdutoTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (ProdutoExistenteException e) {
			Assert.assertTrue(false);
		} catch (ClassificacaoInexistenteException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-10-2 ----
	 * Este teste foi feito para lista produtos por restrio
	 * quando se espera a busca no encontra nenhum resultado. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - O produto "Matrix - Filme" deve estar cadastrado. <br>
	 * <b> - O produto "Filme Fico 1" no deve estar cadastrado. <br>
	 * <b> - O produto "Filme Fico 2" no deve estar cadastrado. <br>
	 * <b> - O produto "Filme Fico 3" no deve estar cadastrado. <br>
	 */
	@Test
	public void pt_10_2(){
		long sessao = 0;
		try {
			sessao = ProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");

			Iterator<Produto> it = ProdutoTest.interfaceWebBD.buscarProdutoRestricoes(new CriterioBusca(TipoProduto.FILME, null, null, null, "NORMAL", null, null));
			Assert.assertTrue(it.hasNext());
			Produto p = it.next();
			Assert.assertNotNull(p);
			Assert.assertTrue(p instanceof Filme);
			Assert.assertTrue(((Filme) p).getNome().equals("Matrix - Filme") || ((Filme) p).getNome().equals("Filme Fico 1"));

			Assert.assertTrue(it.hasNext());
			p = it.next();
			Assert.assertNotNull(p);
			Assert.assertTrue(p instanceof Filme);
			Assert.assertTrue(((Filme) p).getNome().equals("Matrix - Filme") || ((Filme) p).getNome().equals("Filme Fico 1"));

			Assert.assertEquals(false, it.hasNext());
			ProdutoTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-22-1 ----
	 * Este teste foi feito para devolver um produto a uma filial. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - O produto "Matrix - Filme" deve estar cadastrado. <br>
	 */
	@Test
	public void pt_22_1(){
		long sessao;
		try {
			sessao = ProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			
			// Cadastrar novas filiais
			Endereco e2 = new Endereco("Av. Recife", "PE", "Recife", "Boa Viagem", null, 881, 52041060);
			Telefone t = new Telefone(81, 99716907);
			Filial f2 = new Filial("Filial Boa Viagem 2", t, e2);
			ProdutoTest.interfaceWebBD.cadastrarFilial(sessao, f2);

			// Cadastrar novo funcionario
			Filial f = ProdutoTest.interfaceWebBD.buscarFilial("Filial Boa Viagem");
			Funcionario funcionario = new Funcionario(Long.parseLong("32137915472"), "senhateste", "teste", "func@cin.ufpe.br", f);
			ProdutoTest.interfaceWebBD.cadastrarUsuario(sessao, funcionario);

			// Cadastrar cpia para o produto
			Produto produto = ProdutoTest.interfaceWebBD.buscarProduto("Matrix - Filme");
			Copia copia = new Copia(10, f, produto);
			ProdutoTest.interfaceWebBD.cadastrarCopia(sessao, copia);
			
			// Cadastrar o plano
			Plano plano = new Plano(1.0, "plano", "nada", 10,new LinkFoto(TipoLinkFoto.NORMAL, "lalallala"));
			ProdutoTest.interfaceWebBD.cadastrarPlano(sessao, plano);
			
			// Cadastrar cliente
			Cliente cliente = new Cliente(Long.parseLong("08700387452"), "senhanada", "cliente", "videosystem.locadora@gmail.com", plano, e2);
			cliente.setTelefones(new Telefone[]{new Telefone(81, 30303030)});
			ProdutoTest.interfaceWebBD.cadastrarUsuario(sessao, cliente);

			// Cadastrar locao sobre a copia
			Locacao locacao = new Locacao(cliente, copia, new Periodo(new GregorianCalendar(2009, 1, 1), new GregorianCalendar(2009, 1, 5)));
			ProdutoTest.interfaceWebBD.inserirLocacao(sessao, locacao);
			
			ProdutoTest.interfaceWebBD.deslogar(sessao);
			
			sessao = ProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("32137915472"), "senhateste");
			
			ProdutoTest.interfaceWebBD.devolverProduto(sessao, locacao.getCopia().getCodigoCopia(), f2.getNome());
			produto = ProdutoTest.interfaceWebBD.buscarProduto("Matrix - Filme");
			
			Assert.assertTrue(produto.getCopia(10).getFilial().equals(f2));
			
			ProdutoTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (TelefoneInvalidoException e) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (FilialExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaInexistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaExistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (LocacaoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (LocacaoInvalidaException e) {
			Assert.assertTrue(false);
		} catch (PeriodoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (PlanoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (LocacaoExistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaLocadaNoPeriodoException e) {
			Assert.assertTrue(false);
		} catch (CopiaReservadaNoPeriodoException e) {
			Assert.assertTrue(false);
		} catch (PlanoExistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		} catch (LinkFotoInvalidoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-22-2 ----
	 * Este teste foi feito para devolver um produto a uma filial quando
	 * o mesmo no foi locado. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - O Cliente de CPF 08700387452 deve estar cadastrado. <br>
	 * <b> - O produto "Matrix - Filme" deve estar cadastrado. <br>
	 */
	@Test
	public void pt_22_2(){
		long sessao = 0;
		try {
			sessao = ProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			
			Produto produto = ProdutoTest.interfaceWebBD.buscarProduto("Matrix - Filme");
			Copia copia = produto.getCopia(10);
			
			Cliente cliente = (Cliente) ProdutoTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08700387452"));
			Locacao locacao = new Locacao(cliente, copia, new Periodo(new GregorianCalendar(2009, 1, 1), new GregorianCalendar(2009, 1, 5)));
			
			ProdutoTest.interfaceWebBD.deslogar(sessao);
			
			sessao = ProdutoTest.interfaceWebBD.logarUsuario(Long.parseLong("32137915472"), "senhateste");
			
			produto = ProdutoTest.interfaceWebBD.buscarProduto("Matrix - Filme");
			ProdutoTest.interfaceWebBD.devolverProduto(sessao, locacao.getCopia().getCodigoCopia(), "Filial Boa Viagem");
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaInexistenteException e) {
			Assert.assertTrue(false);
		} catch (LocacaoInexistenteException e) {
		} catch (LocacaoInvalidaException e) {
			Assert.assertTrue(false);
		} catch (PeriodoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		}
		
		try {
			ProdutoTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
}
