package testes;

import hibernate.GeradorTabelas;
import hibernate.HibernateTransaction;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;
import java.util.Iterator;

import negocio.exception.PromocaoExistenteException;
import negocio.exception.PromocaoInexistenteException;
import negocio.exception.SenhaInvalidaException;
import negocio.exception.UsuarioInexistenteException;
import negocio.exception.UsuarioLogadoException;
import negocio.exception.UsuarioNaoLogadoException;
import negocio.exception.UsuarioSemPermissaoException;

import org.hibernate.Session;
import org.junit.Assert;
import org.junit.Test;

import dados.exception.CpfInvalidoException;
import dados.exception.EmailInvalidoException;
import dados.exception.LinkFotoInvalidoException;
import dados.exception.NomeInvalidoException;
import dados.exception.PromocaoInvalidaException;
import dados.locacao.Promocao;
import dados.produto.LinkFoto;
import dados.produto.TipoLinkFoto;
import dados.usuario.Administrador;

import servicos.InterfaceWebBD;

/**
 * Esta classe realiza todos os procedimentos de teste relacionados
 * ao gerenciador de promoes. Eventualmente pode utilizar outros gerenciadores
 * como suporte para testar funcionalidades relacionadas. <br><br>
 * 
 *  utilizada a verso do JUnit 4, portanto no precisa que seja estendida
 * de TestCase.
 * @author Lais Sousa
 *
 */
public class PromocaoTest {

	private static InterfaceWebBD interfaceWebBD;

	/**
	 * Limpa o BD e insere o Administrador do sistema
	 */
	@Test
	public void inicializacao(){
		GeradorTabelas.limparBD();
		
		try {
			String ipConfig = String.format("rmi://%s:1099/",InterfaceWebBD.ip);
			PromocaoTest.interfaceWebBD = (InterfaceWebBD) Naming.lookup(ipConfig +	"InterfaceWebBD");
		} catch (MalformedURLException e1) {
			Assert.assertTrue(false);
		} catch (RemoteException e1) {
			Assert.assertTrue(false);
		} catch (NotBoundException e1) {
			Assert.assertTrue(false);
		}
		
		Administrador admin = null;
		
		try {
			admin = new Administrador(Long.parseLong("05497966497"), "password", "admin", "teste@teste.com");
		} catch (NumberFormatException e) {
		} catch (NomeInvalidoException e) {
		} catch (SenhaInvalidaException e) {
		} catch (CpfInvalidoException e) {
		} catch (EmailInvalidoException e) {
		}
		
		HibernateTransaction busca = new HibernateTransaction();
		busca.openSessionBegin();
		Session sessao = busca.getSession();

		sessao.save(admin);

		busca.closeSessionCommit();
	}

	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-12-1 ----
	 * Este teste foi feito para testar a busca das promoes, existindo 
	 * promoes cadastradas no sistema. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 */
	@Test
	public void pt_12_1(){
		try {
			long sessao = PromocaoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			
			Promocao p[] = new Promocao[5];
			for(int i = 0; i < 5; i++){
				p[i] = new Promocao(String.format("Promocao %d", i), String.format("promoo numero %d", i),new LinkFoto(TipoLinkFoto.NORMAL, "lalallala"));
				PromocaoTest.interfaceWebBD.cadastrarPromocao(sessao, p[i]);
			}
			
			Iterator<Promocao> it = PromocaoTest.interfaceWebBD.getPromocoes();
			Assert.assertNotNull(it);
			int ind = 0;
			
			while(it.hasNext()){
				Assert.assertEquals(it.next(), p[ind]);
				ind++;
			}
			
			PromocaoTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (PromocaoInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (PromocaoExistenteException e) {
			Assert.assertTrue(false);
		} catch (PromocaoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (LinkFotoInvalidoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-12-2 ----
	 * Este teste foi feito para testar a busca das promoes, quando no existem 
	 * promoes cadastradas no sistema. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 */
	@Test
	public void pt_12_2(){
		try {
			long sessao = PromocaoTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			
			Promocao p = null;
			Iterator<Promocao> it = PromocaoTest.interfaceWebBD.getPromocoes();
			Assert.assertNotNull(it);
			
			while(it.hasNext()){
				p = it.next();
			}
			
			PromocaoTest.interfaceWebBD.descadastrarPromocao(sessao, p.getNome());
			PromocaoTest.interfaceWebBD.deslogar(sessao);
			
			it = null;
			it = PromocaoTest.interfaceWebBD.getPromocoes();
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (PromocaoInexistenteException e) {
			Assert.assertTrue(false);			
		}
	}

}
