package testes;

import hibernate.GeradorTabelas;
import hibernate.HibernateTransaction;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;
import java.util.GregorianCalendar;

import negocio.exception.ClassificacaoExistenteException;
import negocio.exception.CopiaExistenteException;
import negocio.exception.CopiaInexistenteException;
import negocio.exception.CopiaLocadaNoPeriodoException;
import negocio.exception.CopiaReservadaNoPeriodoException;
import negocio.exception.FilialExistenteException;
import negocio.exception.FilialInexistenteException;
import negocio.exception.FilialNaoLogadaException;
import negocio.exception.LocacaoExistenteException;
import negocio.exception.PlanoExistenteException;
import negocio.exception.ProdutoExistenteException;
import negocio.exception.ProdutoInexistenteException;
import negocio.exception.ReservaExistenteException;
import negocio.exception.ReservaInexistenteException;
import negocio.exception.SenhaInvalidaException;
import negocio.exception.UsuarioExistenteException;
import negocio.exception.UsuarioInexistenteException;
import negocio.exception.UsuarioLogadoException;
import negocio.exception.UsuarioNaoLogadoException;
import negocio.exception.UsuarioSemPermissaoException;

import org.hibernate.Session;
import org.junit.Assert;
import org.junit.Test;

import servicos.InterfaceWebBD;

import dados.exception.CopiaInvalidaException;
import dados.exception.CpfInvalidoException;
import dados.exception.EmailInvalidoException;
import dados.exception.EnderecoInvalidoException;
import dados.exception.FilialInvalidaException;
import dados.exception.LinkFotoInvalidoException;
import dados.exception.LocacaoInvalidaException;
import dados.exception.NomeInvalidoException;
import dados.exception.PeriodoInvalidoException;
import dados.exception.PlanoInvalidoException;
import dados.exception.PrecoInvalidoException;
import dados.exception.ProdutoInvalidoException;
import dados.exception.ReservaInvalidaException;
import dados.exception.TelefoneInvalidoException;
import dados.filial.Endereco;
import dados.filial.Filial;
import dados.locacao.Copia;
import dados.locacao.Locacao;
import dados.locacao.Periodo;
import dados.locacao.Reserva;
import dados.produto.ClassificacaoPreco;
import dados.produto.ClassificacaoPrecoInvalida;
import dados.produto.Filme;
import dados.produto.LinkFoto;
import dados.produto.Produto;
import dados.produto.TipoLinkFoto;
import dados.usuario.Administrador;
import dados.usuario.Cliente;
import dados.usuario.Dependente;
import dados.usuario.Funcionario;
import dados.usuario.Plano;
import dados.usuario.Telefone;

/**
 * Esta classe realiza todos os procedimentos de teste relacionados
 * ao gerenciador de reservas. Eventualmente pode utilizar outros gerenciadores
 * como suporte para testar funcionalidades relacionadas. <br><br>
 * 
 *  utilizada a verso do JUnit 4, portanto no precisa que seja estendida
 * de TestCase.
 * @author Lais Sousa
 *
 */
public class ReservaTest {

	private static InterfaceWebBD interfaceWebBD;

	/**
	 * Limpa o BD e insere o Administrador do sistema
	 */
	@Test
	public void inicializacao(){
		GeradorTabelas.limparBD();
		
		try {
			String ipConfig = String.format("rmi://%s:1099/", InterfaceWebBD.ip);
			ReservaTest.interfaceWebBD = (InterfaceWebBD) Naming.lookup(ipConfig +	"InterfaceWebBD");
		} catch (MalformedURLException e1) {
			Assert.assertTrue(false);
		} catch (RemoteException e1) {
			Assert.assertTrue(false);
		} catch (NotBoundException e1) {
			Assert.assertTrue(false);
		}
		
		Administrador admin = null;
		
		try {
			admin = new Administrador(Long.parseLong("05497966497"), "password", "admin", "teste@teste.com");
		} catch (NumberFormatException e) {
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		}
		
		HibernateTransaction busca = new HibernateTransaction();
		busca.openSessionBegin();
		Session s = busca.getSession();

		s.save(admin);

		busca.closeSessionCommit();
		
		try {
			long sessao = ReservaTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			
			// Cadastrando as classificaes de produto
			ReservaTest.interfaceWebBD.inserirClassificacao(sessao, new ClassificacaoPreco("NORMAL", 5.0));
			ReservaTest.interfaceWebBD.inserirClassificacao(sessao, new ClassificacaoPreco("LANAMENTO", 5.0));
			ReservaTest.interfaceWebBD.inserirClassificacao(sessao, new ClassificacaoPreco("LANAMENTO 24 HORAS", 5.0));
			
			// Cadastrar novo plano
			Plano plano = new Plano(100.00, "Plano V.I.P.", "Plano vip", 50,new LinkFoto(TipoLinkFoto.NORMAL, "lalalla"));
			ReservaTest.interfaceWebBD.cadastrarPlano(sessao, plano);
			
			// Cadastrar novos clientes
			Endereco e = new Endereco("Av. Santos Dumont", "PE", "Recife", "Rosarinho", "Apt 402", 881, 52041060);
			Endereco e1 = new Endereco("Av. Boa Viagem", "PE", "Recife", "Boa Viagem", null, 881, 52041060);
			Cliente cliente = new Cliente(Long.parseLong("08902507408"), "password", "Caio Csar Sabino Silva", "videosystem.locadora@gmail.com",plano,e);
			Cliente cliente2 = new Cliente(Long.parseLong("08150548408"), "mypassword", "Caio Csar", "videosystem.locadora@gmail.com",plano,e1);
			ReservaTest.interfaceWebBD.cadastrarCliente(cliente, new Telefone[]{new Telefone(40, 50505050)});
			ReservaTest.interfaceWebBD.cadastrarCliente(cliente2, new Telefone[]{new Telefone(40, 50505050)});
			
			//Cadastrar novo dependente
			Dependente dependente = new Dependente(Long.parseLong("08700387452"), "senhagrande", "Lais Sousa", "videosystem.locadora@gmail.com", cliente);
			ReservaTest.interfaceWebBD.cadastrarUsuario(sessao, dependente);
			
			// Cadastrar nova filial
			Telefone t = new Telefone(81, 99716907);
			Filial f = new Filial("Filial Boa Viagem", t, e1);
			ReservaTest.interfaceWebBD.cadastrarFilial(sessao, f);
			
			//Cadastrar novo Funcionario
			Funcionario funcionario = new Funcionario(Long.parseLong("32137915472"), "senhateste", "teste", "func@cin.ufpe.br", f);
			ReservaTest.interfaceWebBD.cadastrarUsuario(sessao, funcionario);
			
			//Cadastrar novo produto
			Produto produto = new Filme("Matrix - Filme", "Fico Cientfica", "14 anos", "mto bom!!!", "nao se sabe", "www.link.com.br", "nao se sabe", "irmaos sei que lah", new ClassificacaoPreco("NORMAL", 5.0), 1999, 200);
			ReservaTest.interfaceWebBD.cadastrarProduto(sessao, produto);
			
			//Cadastrar nova copia
			Copia c = new Copia(50, f, produto);
			ReservaTest.interfaceWebBD.cadastrarCopia(sessao, c);
			
			ReservaTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (PlanoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (PlanoExistenteException e) {
			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (PrecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (TelefoneInvalidoException e) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e) {
			Assert.assertTrue(false);
		} catch (FilialExistenteException e) {
			Assert.assertTrue(false);
		} catch (ProdutoExistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (CopiaExistenteException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (ClassificacaoExistenteException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		} catch (ClassificacaoPrecoInvalida e) {
			Assert.assertTrue(false);
		} catch (LinkFotoInvalidoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-19-1 ----
	 * Este teste foi feito para testar a reserva de produtos feita online com sucesso. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O Cliente de CPF 08902507408 deve estar cadastrado. <br>
	 * <b> - O Cliente de CPF 08902507408 no deve estar logado. <br>
	 * <b> - O Filme "Matrix - Filme" deve estar cadastrado e deve possuir uma cpia. <br>
	 * 
	 */
	@Test
	public void pt_19_1(){
		long sessao = 0;
		
		try {
			sessao = ReservaTest.interfaceWebBD.logarUsuario(Long.parseLong("32137915472"), "senhateste");

			Cliente cliente = (Cliente) ReservaTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08902507408"));
			Produto produto = ReservaTest.interfaceWebBD.buscarProduto("Matrix - Filme");
			Periodo periodo = new Periodo(new GregorianCalendar(2009, 1, 1), new GregorianCalendar(2009, 1, 5));
			
			Reserva reserva = new Reserva(cliente, produto.getCopia(50), periodo);
			ReservaTest.interfaceWebBD.inserirReserva(sessao, reserva);
			
			ReservaTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (PeriodoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (CopiaInexistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaLocadaNoPeriodoException e) {
			Assert.assertTrue(false);
		} catch (CopiaReservadaNoPeriodoException e) {
			Assert.assertTrue(false);
		} catch (ReservaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ReservaExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialNaoLogadaException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-19-2 ----
	 * Este teste foi feito para testar a reserva de produtos feita
	 * por um funcionrio em uma filial com sucesso. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O Cliente de CPF 08902507408 deve estar cadastrado. <br>
	 * <b> - O Cliente de CPF 08902507408 no deve estar logado. <br>
	 * <b> - O Filme "Matrix - Filme" deve estar cadastrado e deve possuir uma cpia. <br>
	 * 
	 */
	@Test
	public void pt_19_2(){
		long sessao = 0;
		
		try {
			sessao = ReservaTest.interfaceWebBD.logarUsuario(Long.parseLong("08902507408"), "password");

			Cliente cliente = (Cliente) ReservaTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08902507408"));
			Produto produto = ReservaTest.interfaceWebBD.buscarProduto("Matrix - Filme");
			Periodo periodo = new Periodo(new GregorianCalendar(2009, 2, 1), new GregorianCalendar(2009, 2, 5));
			
			Reserva reserva = new Reserva(cliente, produto.getCopia(50), periodo);
			ReservaTest.interfaceWebBD.inserirReserva(sessao, reserva);
			
			ReservaTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (PeriodoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (CopiaInexistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaLocadaNoPeriodoException e) {
			Assert.assertTrue(false);
		} catch (CopiaReservadaNoPeriodoException e) {
			Assert.assertTrue(false);
		} catch (ReservaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ReservaExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialNaoLogadaException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-19-1 ----
	 * Este teste foi feito para testar a reserva de um produto j locado. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O Cliente de CPF 08902507408 deve estar cadastrado. <br>
	 * <b> - O Cliente de CPF 08902507408 no deve estar logado. <br>
	 * <b> - O Filme "Matrix - Filme" deve estar cadastrado e deve possuir uma cpia. <br>
	 * 
	 */
	@Test
	public void pt_19_4(){
		long sessao = 0;
		
		try {
			sessao = ReservaTest.interfaceWebBD.logarUsuario(Long.parseLong("32137915472"), "senhateste");
			
			Cliente cliente = (Cliente) ReservaTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08902507408"));
			Produto produto = ReservaTest.interfaceWebBD.buscarProduto("Matrix - Filme");
			Periodo periodo = new Periodo(new GregorianCalendar(2009, 1, 1), new GregorianCalendar(2009, 1, 5));
			Locacao locacao = new Locacao(cliente, produto.getCopia(50), periodo);
			
			ReservaTest.interfaceWebBD.inserirLocacao(sessao, locacao);
			
			Reserva reserva = new Reserva(cliente, produto.getCopia(50), periodo);
			ReservaTest.interfaceWebBD.inserirReserva(sessao, reserva);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (PeriodoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (CopiaInexistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaLocadaNoPeriodoException e) {
		} catch (CopiaReservadaNoPeriodoException e) {
			Assert.assertTrue(false);
		} catch (ReservaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ReservaExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (LocacaoInvalidaException e) {
			Assert.assertTrue(false);
		} catch (LocacaoExistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialNaoLogadaException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		}
		
		try {
			ReservaTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-19-5 ----
	 * Este teste foi feito para testar a reserva de um produto
	 * j reservado por um outro usurio. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O Cliente de CPF 08902507408 deve estar cadastrado. <br>
	 * <b> - O Cliente de CPF 08902507408 no deve estar logado. <br>
	 * <b> - O Filme "Matrix - Filme" deve estar cadastrado e deve possuir uma cpia. <br>
	 * 
	 */
	@Test
	public void pt_19_5(){
		long sessao = 0;
		
		try {
			sessao = ReservaTest.interfaceWebBD.logarUsuario(Long.parseLong("08150548408"), "mypassword");

			Cliente cliente = (Cliente) ReservaTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08150548408"));
			Produto produto = ReservaTest.interfaceWebBD.buscarProduto("Matrix - Filme");
			Periodo periodo = new Periodo(new GregorianCalendar(2009, 1, 30), new GregorianCalendar(2009, 2, 15));
			
			Reserva reserva = new Reserva(cliente, produto.getCopia(50), periodo);
			ReservaTest.interfaceWebBD.inserirReserva(sessao, reserva);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (PeriodoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (CopiaInexistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaLocadaNoPeriodoException e) {
			Assert.assertTrue(false);
		} catch (CopiaReservadaNoPeriodoException e) {
		} catch (ReservaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ReservaExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialNaoLogadaException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		}
		
		try {
			ReservaTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-19-6 ----
	 * Este teste foi feito para testar a reserva de um produto
	 * j reservado pelo mesmo usurio. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O Cliente de CPF 08902507408 deve estar cadastrado. <br>
	 * <b> - O Cliente de CPF 08902507408 no deve estar logado. <br>
	 * <b> - O Filme "Matrix - Filme" deve estar cadastrado e deve possuir uma cpia. <br>
	 * 
	 */
	@Test
	public void pt_19_6(){
		long sessao = 0;
		
		try {
			sessao = ReservaTest.interfaceWebBD.logarUsuario(Long.parseLong("08902507408"), "password");

			Cliente cliente = (Cliente) ReservaTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08902507408"));
			Produto produto = ReservaTest.interfaceWebBD.buscarProduto("Matrix - Filme");
			Periodo periodo = new Periodo(new GregorianCalendar(2009, 1, 30), new GregorianCalendar(2009, 2, 5));
			
			Reserva reserva = new Reserva(cliente, produto.getCopia(50), periodo);
			ReservaTest.interfaceWebBD.inserirReserva(sessao, reserva);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (PeriodoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (CopiaInexistenteException e) {
			Assert.assertTrue(false);
		} catch (CopiaLocadaNoPeriodoException e) {
			Assert.assertTrue(false);
		} catch (CopiaReservadaNoPeriodoException e) {
		} catch (ReservaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ReservaExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialNaoLogadaException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		}
		
		try {
			ReservaTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-20 ----
	 * Este teste foi feito para testar o cancelamento de uma reserva de um produto com sucesso. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O Cliente de CPF 08902507408 deve estar cadastrado. <br>
	 * <b> - O Cliente de CPF 08902507408 no deve estar logado. <br>
	 * <b> - O Filme "Matrix - Filme" deve estar cadastrado e deve possuir uma cpia. <br>
	 * 
	 */
	@Test
	public void pt_20(){
		long sessao = 0;
		
		try {
			sessao = ReservaTest.interfaceWebBD.logarUsuario(Long.parseLong("08902507408"), "password");

			Cliente cliente = (Cliente) ReservaTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08902507408"));
			
			ReservaTest.interfaceWebBD.removerReserva(sessao, cliente.getCpf(), 50);
			
			ReservaTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (CopiaInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (ProdutoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (ReservaInexistenteException e) {
			Assert.assertTrue(false);
		}
	}
}
