package testes;

import hibernate.GeradorTabelas;
import hibernate.HibernateTransaction;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;

import org.hibernate.Session;
import org.junit.Assert;
import org.junit.Test;

import servicos.InterfaceWebBD;

import negocio.exception.FilialExistenteException;
import negocio.exception.FilialInexistenteException;
import negocio.exception.PlanoExistenteException;
import negocio.exception.PlanoInexistenteException;
import negocio.exception.SenhaInvalidaException;
import negocio.exception.UsuarioExistenteException;
import negocio.exception.UsuarioInexistenteException;
import negocio.exception.UsuarioLogadoException;
import negocio.exception.UsuarioNaoLogadoException;
import negocio.exception.UsuarioSemPermissaoException;
import dados.exception.CpfInvalidoException;
import dados.exception.EmailInvalidoException;
import dados.exception.EnderecoInvalidoException;
import dados.exception.FilialInvalidaException;
import dados.exception.LinkFotoInvalidoException;
import dados.exception.NomeInvalidoException;
import dados.exception.PlanoInvalidoException;
import dados.exception.TelefoneInvalidoException;
import dados.filial.Endereco;
import dados.filial.Filial;
import dados.produto.LinkFoto;
import dados.produto.TipoLinkFoto;
import dados.usuario.Administrador;
import dados.usuario.Cliente;
import dados.usuario.Dependente;
import dados.usuario.Funcionario;
import dados.usuario.Plano;
import dados.usuario.Telefone;
import dados.usuario.Usuario;

/**
 * Esta classe realiza todos os procedimentos de teste relacionados
 * ao gerenciador de usurio. Eventualmente pode utilizar outros gerenciadores
 * como suporte para testar funcionalidades de dados de usurios. <br><br>
 * 
 *  utilizada a verso do JUnit 4, portanto no precisa que seja estendida
 * de TestCase.
 * @author Caio Csar
 *
 */
public class UsuarioTest{

	private static InterfaceWebBD interfaceWebBD;

	/**
	 * Limpa o BD e insere o Administrador do sistema
	 */
	@Test
	public void inicializacao(){
		GeradorTabelas.limparBD();
		
		try {
			String ipConfig = String.format("rmi://%s:1099/", InterfaceWebBD.ip);
			UsuarioTest.interfaceWebBD = (InterfaceWebBD) Naming.lookup(ipConfig +	"InterfaceWebBD");
		} catch (MalformedURLException e1) {
			Assert.assertTrue(false);
		} catch (RemoteException e1) {
			Assert.assertTrue(false);
		} catch (NotBoundException e1) {
			Assert.assertTrue(false);
		}
		
		Administrador admin = null;
		
		try {
			admin = new Administrador(Long.parseLong("05497966497"), "password", "admin", "teste@teste.com");
		} catch (NumberFormatException e) {
		} catch (NomeInvalidoException e) {
		} catch (SenhaInvalidaException e) {
		} catch (CpfInvalidoException e) {
		} catch (EmailInvalidoException e) {
		}
		
		HibernateTransaction busca = new HibernateTransaction();
		busca.openSessionBegin();
		Session sessao = busca.getSession();

		sessao.save(admin);

		busca.closeSessionCommit();
	}

	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-01-1 ----
	 * Este teste foi feito para testar um cadastro dos trs tipos de usurio com sucesso. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - A Filial "Filial Boa Viagem" no deve estar cadastrada. <br>
	 */
	@Test
	public void pt_01_1(){
		try {
			Administrador administrador = new Administrador(Long.parseLong("09317891411"), "password", "admin2", "admin2@videosystem.com");

			long sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			Plano plano = new Plano(100.00, "Plano V.I.P.", "Plano vip", 50,new LinkFoto(TipoLinkFoto.NORMAL, "lallala"));
			UsuarioTest.interfaceWebBD.cadastrarPlano(sessao, plano);
			
			plano = null;
			plano = UsuarioTest.interfaceWebBD.buscarPlano("Plano V.I.P.");
			
			Assert.assertNotNull(plano);

			Endereco e = new Endereco("Av. Santos Dumont", "PE", "Recife", "Rosarinho", "Apt 402", 881, 52041060);
			Endereco e1 = new Endereco("Av. Boa Viagem", "PE", "Recife", "Boa Viagem", null, 881, 52041060);
			Cliente usuario = new Cliente(Long.parseLong("08387667498"), "password", "Caio Csar Sabino Silva", "videosystem.locadora@gmail.com",plano,e);
			
			Telefone t = new Telefone(81, 99716907);
			Filial f = new Filial("Filial Boa Viagem", t, e1);
			UsuarioTest.interfaceWebBD.cadastrarFilial(sessao, f);
			
			f = null;
			f = UsuarioTest.interfaceWebBD.buscarFilial("Filial Boa Viagem");
			
			Assert.assertNotNull(f);
			
			Funcionario funcionario = new Funcionario(Long.parseLong("05631071460"), "password", "Funcionario do mes", "funcionario@videosystem.com", f);
			
			UsuarioTest.interfaceWebBD.cadastrarUsuario(sessao, usuario);
			UsuarioTest.interfaceWebBD.cadastrarUsuario(sessao, administrador);
			UsuarioTest.interfaceWebBD.cadastrarUsuario(sessao, funcionario);

			Administrador administradorInserido = (Administrador) UsuarioTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("09317891411"));
			Assert.assertNotNull(administradorInserido);
			Assert.assertEquals(administradorInserido, administrador);

			Funcionario funcionarioInserido = (Funcionario) UsuarioTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("05631071460"));
			Assert.assertNotNull(funcionarioInserido);
			Assert.assertEquals(funcionarioInserido, funcionario);
			
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (PlanoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (PlanoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (TelefoneInvalidoException e) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e) {
			Assert.assertTrue(false);
		} catch (PlanoExistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialExistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		} catch (LinkFotoInvalidoException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-01-2 ----
	 * Este teste foi feito para testar um cadastro com dados invlidos. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O Plano "Plano V.I.P." deve estar cadastrado. <br>
	 */
	@Test
	public void pt_01_2(){
		try {
			Plano plano = UsuarioTest.interfaceWebBD.buscarPlano("Plano V.I.P.");
			Endereco e = new Endereco("Av. Santos Dumont", "PE", "Recife", "Rosarinho", "Apt 402", 881, 52041060);
			Cliente usuario = new Cliente(Long.parseLong("08387667498"), "mypassword", "Usurio Invlido", "invalid",plano,e);

			UsuarioTest.interfaceWebBD.cadastrarCliente(usuario, new Telefone[]{new Telefone(80, 30303030)});

			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (PlanoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (TelefoneInvalidoException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (PlanoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-01-3 ----
	 * Este teste foi feito para testar um cadastro de um cliente j existente. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O Plano "Plano V.I.P." deve estar cadastrado. <br>
	 * <b> - Algum usurio com CPF 089025074-08 j est cadastrado. <br>
	 */
	@Test
	public void pt_01_3(){
		try {
			Plano plano = UsuarioTest.interfaceWebBD.buscarPlano("Plano V.I.P.");
			Endereco e = new Endereco("Av. Santos Dumont", "PE", "Recife", "Rosarinho", "Apt 402", 881, 52041060);
			Cliente usuario = new Cliente(Long.parseLong("08387667498"), "mypassword", "Usurio OK", "videosystem.locadora@gmail.com",plano,e);

			UsuarioTest.interfaceWebBD.cadastrarCliente(usuario, new Telefone[]{new Telefone(80, 30303030)});

			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
		} catch (PlanoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (TelefoneInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (PlanoInvalidoException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-02-1 ----
	 * Este teste foi feito para testar uma alterao
	 * de um cadastro de um cliente quando a operao
	 * obtm sucesso. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - Algum cliente com CPF 089025074-08 j est cadastrado. <br>
	 * <b> - O cliente com CPF 089025074-08 no est logado. <br>
	 * <b> - O cliente com CPF 089025074-08 possui um nome diferente de "Novo nome". <br>
	 * <b> - O cliente com CPF 089025074-08 possui senha "mypassword". <br>
	 */
	@Test
	public void pt_02_1(){
		try {
			long sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08387667498"), "password");
			
			Cliente c = (Cliente) UsuarioTest.interfaceWebBD.buscarUsuario(sessao,Long.parseLong("08387667498"));
			Cliente usuario = new Cliente(Long.parseLong("08387667498"), "mypassword", "Novo nome", "videosystem.locadora@gmail.com",c.getPlano(),c.getEndereco());

			UsuarioTest.interfaceWebBD.alterarDadosUsuario(sessao, usuario);

			Usuario u = UsuarioTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08387667498"));
			Assert.assertNotNull(u);
			Assert.assertEquals(u, usuario);
			Assert.assertEquals(u.getNome(), usuario.getNome());
			
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (PlanoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-02-2 ----
	 * Este teste foi feito para testar uma alterao
	 * de um cadastro de um cliente quando os novos dados
	 * so invlidos. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - Algum cliente com CPF 089025074-08 j est cadastrado. <br>
	 * <b> - O cliente com CPF 089025074-08 no est logado. <br>
	 * <b> - O cliente com CPF 089025074-08 possui senha "mypassword". <br>
	 */
	@Test
	public void pt_02_2(){
		long sessao = 0;

		try {
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08387667498"), "mypassword");
			
			Cliente c = (Cliente) UsuarioTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08387667498"));
			Cliente usuario = new Cliente(Long.parseLong("08387667498"), "password", "Novo nome", "emailInvalido",c.getPlano(),c.getEndereco());

			UsuarioTest.interfaceWebBD.alterarDadosUsuario(sessao, usuario);
			Assert.assertTrue(false);
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (PlanoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			try {
				UsuarioTest.interfaceWebBD.deslogar(sessao);
			} catch (RemoteException e1) {
				Assert.assertTrue(false);
			} catch (UsuarioNaoLogadoException e1) {
				Assert.assertTrue(false);
			}
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-03-1 ----
	 * Este teste foi feito para testar uma remoo
	 * de um cadastro de um cliente quando a operao
	 * tem sucesso. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - Algum cliente com CPF 089025074-08 j est cadastrado. <br>
	 */
	@Test(timeout = 20000)
	public void pt_03_1(){
		try {
			long sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08387667498"), "mypassword");
			UsuarioTest.interfaceWebBD.descadastrarUsuario(sessao, Long.parseLong("08387667498"), "mypassword");
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		}

		try {
			UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08387667498"), "mypassword");
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-03-2 ----
	 * Este teste foi feito para testar uma remoo
	 * de um cadastro de um cliente quando o cliente
	 * no existe. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - No existe cliente com CPF 089025074-08 cadastrado. <br>
	 */
	@Test
	public void pt_03_2(){
		long sessao = 0;
		
		try {
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			UsuarioTest.interfaceWebBD.descadastrarUsuario(sessao, Long.parseLong("08387667498"), "mypassword");
			Assert.assertTrue(false);
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			try {
				UsuarioTest.interfaceWebBD.deslogar(sessao);
				Assert.assertTrue(true);
			} catch (UsuarioNaoLogadoException e1) {
				Assert.assertTrue(false);
			} catch (RemoteException e1) {
				Assert.assertTrue(false);
			}
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-03-3 ----
	 * Este teste foi feito para testar uma remoo
	 * de um cadastro de um cliente quando o usurio
	 * passa uma senha incorreta. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O admin est cadastrado e no est logado. <br>
	 * <b> - O admin possui senha diferente de "wrongpassword". <br>
	 */
	@Test
	public void pt_03_3(){
		long sessao = 0;
		
		try {
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			UsuarioTest.interfaceWebBD.descadastrarUsuario(sessao, Long.parseLong("05497966497"), "wrongpassword");
			Assert.assertTrue(false);
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			try {
				UsuarioTest.interfaceWebBD.deslogar(sessao);
			} catch (UsuarioNaoLogadoException e1) {
				Assert.assertTrue(false);
			} catch (RemoteException e1) {
				Assert.assertTrue(false);
			}
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		}
	}

	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-03-4 ----
	 * Este teste verifica se o sistema nega permisso ao usurio
	 * para realizar operaes de cadastro e remoo de cadastros
	 * quando o mesmo no possui permisso para tal operao.
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O admin est cadastrado e no est logado. <br>
	 * <b> - O admin possui senha igual a "password". <br>
	 */
	@Test
	public void pt_03_4(){
		long sessao = 0; 
		Cliente usuario = null;
		
		try {
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			Plano plano = UsuarioTest.interfaceWebBD.buscarPlano("Plano V.I.P.");
			
			Endereco e = new Endereco("Av. Santos Dumont", "PE", "Recife", "Rosarinho", "Apt 402", 881, 52041060);
			usuario = new Cliente(Long.parseLong("08387667498"), "password", "Caio Csar Sabino Silva", "videosystem.locadora@gmail.com",plano,e);
			UsuarioTest.interfaceWebBD.cadastrarUsuario(sessao, usuario);
			
			UsuarioTest.interfaceWebBD.deslogar(sessao);
			
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(usuario.getCpf(), usuario.getSenha());
			
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (PlanoInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (PlanoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		}
		
		try {
			UsuarioTest.interfaceWebBD.cadastrarUsuario(sessao, new Administrador(Long.parseLong("08700387452"), "senhagrande", "nome", "videosystem.locadora@gmail.com"));
			Assert.assertTrue(false);

		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		}
		
		try {
			Endereco e1 = new Endereco("Av. Boa Viagem", "PE", "Recife", "Boa Viagem", null, 881, 52041060);
			Telefone t = new Telefone(81, 99716907);
			Filial filial = new Filial("filial", t, e1);
			
			UsuarioTest.interfaceWebBD.cadastrarUsuario(sessao, new Funcionario(Long.parseLong("32137915472"), "senhateste", "teste", "lsa@cin.ufpe.br", filial));
			Assert.assertTrue(false);

		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (EnderecoInvalidoException e) {
			Assert.assertTrue(false);
		} catch (TelefoneInvalidoException e) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e) {
			Assert.assertTrue(false);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		}
		
		try {
			UsuarioTest.interfaceWebBD.descadastrarUsuario(sessao, Long.parseLong("05497966497"), usuario.getSenha());
			Assert.assertTrue(false);

		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		}
		
		try {
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-04-1 ----
	 * Este procedimento testa o cadastro de um Dependente com sucesso no sistema.
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * 
	 * <b> - O admin est cadastrado e no est logado. <br>
	 * <b> - O admin possui senha igual a "password". <br>
	 */
	@Test
	public void pt_04_1(){
		try {
			long sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			Cliente cliente = (Cliente) UsuarioTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08387667498"));
			UsuarioTest.interfaceWebBD.deslogar(sessao);
			Assert.assertNotNull(cliente);
			
			Dependente dependente = new Dependente(Long.parseLong("08700387452"), "senhagrande", "Lais Sousa", "videosystem.locadora@gmail.com", cliente);
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(cliente.getCpf(), cliente.getSenha());
			UsuarioTest.interfaceWebBD.cadastrarUsuario(sessao, dependente);
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-04-2 ----
	 * Este procedimento testa o cadastro de um Dependente com dados
	 * invlidos no sistema.
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O admin est cadastrado e no est logado. <br>
	 * <b> - O admin possui senha igual a "password". <br>
	 * <b> - O dependente com CPF 087003874-52 est cadastrado. <br>
	 */
	@Test
	public void pt_04_2(){
		long sessao = 0;
		
		try {
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			UsuarioTest.interfaceWebBD.cadastrarUsuario(sessao, new Dependente(Long.parseLong("123456789"), "senhateste", "teste", "emailinvalido", new Cliente()));
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		}
		
		try {
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-04-3 ----
	 * Este procedimento testa o cadastro de um Dependente j cadastrado no sistema.
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O admin est cadastrado e no est logado. <br>
	 * <b> - O admin possui senha igual a "password". <br>
	 * <b> - O cliente com CPF 089025074-08 est cadastrado e no est logado. <br>
	 */
	@Test
	public void pt_04_3(){
		long sessao = 0;
		try {
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			Cliente cliente = (Cliente) UsuarioTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08387667498"));
			Assert.assertNotNull(cliente);
			UsuarioTest.interfaceWebBD.cadastrarUsuario(sessao, new Dependente(Long.parseLong("08700387452"), "senhagrande", "Lais Sousa", "lsa@cin.ufpe.br", cliente));
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		}
		
		try {
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-05-1 ----
	 * Este procedimento testa a modificao dos dados de um dependente com sucesso.
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O cliente com CPF 089025074-08 est cadastrado e no est logado. <br>
	 * <b> - O dependente com CPF 087003874-52 est cadastrado e no est logado. <br>
	 */
	@Test
	public void pt_05_1(){
		try {
			long sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08700387452"), "senhagrande");
			Dependente dependente = (Dependente) UsuarioTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08700387452"));
			UsuarioTest.interfaceWebBD.alterarDadosUsuario(sessao, new Dependente(Long.parseLong("08700387452"), "novasenha", "Lais Sousa", "lsa@cin.ufpe.br", dependente.getCliente()));
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-05-2 ----
	 * Este procedimento testa a modificao dos dados de um dependente passando-se
	 * dados invlidos ao sistema.
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O cliente com CPF 089025074-08 est cadastrado e no est logado. <br>
	 * <b> - O dependente com CPF 087003874-52 est cadastrado e no est logado. <br>
	 */
	@Test
	public void pt_05_2(){
		long sessao = 0;
		try {
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08700387452"), "novasenha");
			Dependente dependente = (Dependente) UsuarioTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08700387452"));
			UsuarioTest.interfaceWebBD.alterarDadosUsuario(sessao, new Dependente(Long.parseLong("08700387452"), "novasenha", "Lais Sousa", "emailinvalido", dependente.getCliente()));
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
		}
		
		try {
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-06-1 ----
	 * Este procedimento testa a remoo de um dependente com sucesso.
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O cliente com CPF 089025074-08 est cadastrado e no est logado. <br>
	 * <b> - O dependente com CPF 087003874-52 est cadastrado e no est logado. <br>
	 */
	@Test
	public void pt_06_1(){
		try {
			long sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08700387452"), "novasenha");
			UsuarioTest.interfaceWebBD.descadastrarUsuario(sessao, Long.parseLong("08700387452"), "novasenha");
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-06-2 ----
	 * Este procedimento testa a remoo de um dependente passando-se a senha incorreta.
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O cliente com CPF 089025074-08 est cadastrado e no est logado. <br>
	 * <b> - O cliente com CPF 089025074-08 possui senha "password". <br>
	 */
	@Test
	public void pt_06_2(){
		long sessao = 0;
		
		try {
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08387667498"), "password");
			Cliente cliente = (Cliente) UsuarioTest.interfaceWebBD.buscarUsuario(sessao, Long.parseLong("08387667498"));
			UsuarioTest.interfaceWebBD.cadastrarUsuario(sessao, new Dependente(Long.parseLong("08700387452"), "senhagrande", "Lais Sousa", "lsa@cin.ufpe.br", cliente));
			UsuarioTest.interfaceWebBD.descadastrarUsuario(sessao, Long.parseLong("08700387452"), "senhaincorreta");
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		}
		
		try {
			UsuarioTest.interfaceWebBD.deslogar(sessao);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-15-1 ----
	 * Este teste foi feito para testar a efetuao do login feito com sucesso
	 * por todos os tipos de usurio. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 * <b> - A Filial "Filial Boa Viagem" deve estar cadastrada. <br>
	 */
	@Test
	public void pt_15_1(){
		long sessao = 0;
		
		try {
			//Logar administrador
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			
			Filial filial = UsuarioTest.interfaceWebBD.buscarFilial("Filial Boa Viagem");
			Funcionario funcionario = new Funcionario(Long.parseLong("32137915472"), "senhateste", "teste", "email@cin.ufpe.br", filial);
			UsuarioTest.interfaceWebBD.cadastrarUsuario(sessao, funcionario);
			
			UsuarioTest.interfaceWebBD.deslogar(sessao);
			
			//Logar funcionario
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(funcionario.getCpf(), "senhateste");
			UsuarioTest.interfaceWebBD.deslogar(sessao);
			
			//Logar cliente
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08387667498"), "password");
			UsuarioTest.interfaceWebBD.deslogar(sessao);
			
			//Logar dependente
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08700387452"), "senhagrande");
			UsuarioTest.interfaceWebBD.deslogar(sessao);
			
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioSemPermissaoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioExistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialInexistenteException e) {
			Assert.assertTrue(false);
		} catch (FilialInvalidaException e) {
			Assert.assertTrue(false);
		} catch (NomeInvalidoException e) {
			Assert.assertTrue(false);
		} catch (CpfInvalidoException e) {
			Assert.assertTrue(false);
		} catch (EmailInvalidoException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-15-2 ----
	 * Este teste foi feito para testar a efetuao do login feito passando-se login inexistente. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 */
	@Test
	public void pt_15_2(){
		try {
			UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("123456789"), "password");
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-15-3 ----
	 * Este teste foi feito para testar a efetuao do login feito passando-se senha invlido. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 */
	@Test
	public void pt_15_3(){
		try {
			UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "senhaincorrreta");
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-15-4 ----
	 * Este teste foi feito para testar a efetuao do login feito sem o
	 * fornecimento do login como dado. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 */
	@Test
	public void pt_15_4(){
		try {
			UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong(""), "password");
		} catch (NumberFormatException e) {
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-15-5 ----
	 * Este teste foi feito para testar a efetuao do login feito sem o
	 * fornecimento da senha como dado. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 */
	@Test
	public void pt_15_5(){
		try {
			UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "");
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
		}
	}
	
	/**
	 * [OK] ---- PROCEDIMENTO DE TESTE PT-16 ----
	 * Este teste foi feito para testar a efetuao do logoff feito com sucesso
	 * para todos os tipos de usurio. <br> <br>
	 * 
	 * PRECONDIES: <br> <br>
	 * 
	 * <b> - O administrador admin j deve estar cadastrado no BD. <br>
	 * <b> - O administrador admin no deve estar logado. <br>
	 * <b> - O administrador admin deve ter senha "password". <br>
	 */
	@Test
	public void pt_16(){
		long sessao = 0;
		
		try {
			// Deslogar administrador			
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("05497966497"), "password");
			UsuarioTest.interfaceWebBD.deslogar(sessao);
			
			//Deslogar funcionario
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("32137915472"), "senhateste");
			UsuarioTest.interfaceWebBD.deslogar(sessao);
			
			//Deslogar cliente
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08387667498"), "password");
			UsuarioTest.interfaceWebBD.deslogar(sessao);
			
			//Deslogar dependente
			sessao = UsuarioTest.interfaceWebBD.logarUsuario(Long.parseLong("08700387452"), "senhagrande");
			UsuarioTest.interfaceWebBD.deslogar(sessao);
			
		} catch (NumberFormatException e) {
			Assert.assertTrue(false);
		} catch (RemoteException e) {
			Assert.assertTrue(false);
		} catch (UsuarioLogadoException e) {
			Assert.assertTrue(false);
		} catch (UsuarioInexistenteException e) {
			Assert.assertTrue(false);
		} catch (SenhaInvalidaException e) {
			Assert.assertTrue(false);
		} catch (UsuarioNaoLogadoException e) {
			Assert.assertTrue(false);
		}
	}
	
}
